# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gui.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1007, 934)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.line_3 = QtWidgets.QFrame(self.centralwidget)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.gridLayout_8.addWidget(self.line_3, 3, 0, 1, 1)
        self.frame_21 = QtWidgets.QFrame(self.centralwidget)
        self.frame_21.setMinimumSize(QtCore.QSize(0, 46))
        self.frame_21.setMaximumSize(QtCore.QSize(16777215, 46))
        self.frame_21.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_21.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_21.setObjectName("frame_21")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.frame_21)
        self.horizontalLayout_7.setProperty("margin", 0)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setSpacing(0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.frame_29 = QtWidgets.QFrame(self.frame_21)
        self.frame_29.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_29.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_29.setObjectName("frame_29")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self.frame_29)
        self.verticalLayout_25.setProperty("margin", 0)
        self.verticalLayout_25.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_25.setSpacing(0)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.frame_31 = QtWidgets.QFrame(self.frame_29)
        self.frame_31.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_31.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_31.setObjectName("frame_31")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(self.frame_31)
        self.horizontalLayout_22.setProperty("margin", 0)
        self.horizontalLayout_22.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_22.setSpacing(0)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.label_7 = QtWidgets.QLabel(self.frame_31)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_22.addWidget(self.label_7)
        self.currentOutputPath = QtWidgets.QLineEdit(self.frame_31)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        self.currentOutputPath.setPalette(palette)
        self.currentOutputPath.setFrame(False)
        self.currentOutputPath.setReadOnly(True)
        self.currentOutputPath.setObjectName("currentOutputPath")
        self.horizontalLayout_22.addWidget(self.currentOutputPath)
        self.verticalLayout_25.addWidget(self.frame_31)
        self.frame_30 = QtWidgets.QFrame(self.frame_29)
        self.frame_30.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_30.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_30.setObjectName("frame_30")
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout(self.frame_30)
        self.horizontalLayout_23.setProperty("margin", 0)
        self.horizontalLayout_23.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_23.setSpacing(0)
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.label_13 = QtWidgets.QLabel(self.frame_30)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_23.addWidget(self.label_13)
        self.currentInitFile = QtWidgets.QLineEdit(self.frame_30)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        self.currentInitFile.setPalette(palette)
        self.currentInitFile.setFrame(False)
        self.currentInitFile.setReadOnly(True)
        self.currentInitFile.setObjectName("currentInitFile")
        self.horizontalLayout_23.addWidget(self.currentInitFile)
        self.verticalLayout_25.addWidget(self.frame_30)
        self.horizontalLayout_7.addWidget(self.frame_29)
        self.label_10 = QtWidgets.QLabel(self.frame_21)
        self.label_10.setMinimumSize(QtCore.QSize(136, 46))
        self.label_10.setMaximumSize(QtCore.QSize(136, 46))
        self.label_10.setText("")
        self.label_10.setScaledContents(True)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_7.addWidget(self.label_10)
        self.gridLayout_8.addWidget(self.frame_21, 7, 0, 1, 2)
        self.line_2 = QtWidgets.QFrame(self.centralwidget)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridLayout_8.addWidget(self.line_2, 6, 0, 1, 1)
        self.gridLayout_11 = QtWidgets.QGridLayout()
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.saveButton = QtWidgets.QToolButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.saveButton.sizePolicy().hasHeightForWidth()
        )
        self.saveButton.setSizePolicy(sizePolicy)
        self.saveButton.setMinimumSize(QtCore.QSize(74, 28))
        self.saveButton.setMaximumSize(QtCore.QSize(74, 28))
        self.saveButton.setAutoFillBackground(True)
        self.saveButton.setText("")
        self.saveButton.setPopupMode(QtWidgets.QToolButton.DelayedPopup)
        self.saveButton.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.saveButton.setAutoRaise(False)
        self.saveButton.setObjectName("saveButton")
        self.gridLayout_11.addWidget(self.saveButton, 0, 1, 1, 1)
        self.saveCurrentButton = QtWidgets.QToolButton(self.centralwidget)
        self.saveCurrentButton.setMinimumSize(QtCore.QSize(67, 28))
        self.saveCurrentButton.setMaximumSize(QtCore.QSize(67, 28))
        self.saveCurrentButton.setAutoFillBackground(True)
        self.saveCurrentButton.setText("")
        self.saveCurrentButton.setObjectName("saveCurrentButton")
        self.gridLayout_11.addWidget(self.saveCurrentButton, 0, 0, 1, 1)
        self.saveDefaults = QtWidgets.QToolButton(self.centralwidget)
        self.saveDefaults.setMinimumSize(QtCore.QSize(87, 28))
        self.saveDefaults.setMaximumSize(QtCore.QSize(87, 28))
        self.saveDefaults.setAutoFillBackground(True)
        self.saveDefaults.setText("")
        self.saveDefaults.setObjectName("saveDefaults")
        self.gridLayout_11.addWidget(self.saveDefaults, 0, 5, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout_11.addItem(spacerItem, 0, 6, 1, 1)
        self.recompile = QtWidgets.QToolButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.recompile.sizePolicy().hasHeightForWidth()
        )
        self.recompile.setSizePolicy(sizePolicy)
        self.recompile.setMinimumSize(QtCore.QSize(107, 28))
        self.recompile.setMaximumSize(QtCore.QSize(107, 28))
        self.recompile.setAutoFillBackground(True)
        self.recompile.setText("")
        self.recompile.setObjectName("recompile")
        self.gridLayout_11.addWidget(self.recompile, 0, 7, 1, 1)
        self.loadButton = QtWidgets.QToolButton(self.centralwidget)
        self.loadButton.setMinimumSize(QtCore.QSize(67, 28))
        self.loadButton.setMaximumSize(QtCore.QSize(67, 28))
        self.loadButton.setAutoFillBackground(True)
        self.loadButton.setText("")
        self.loadButton.setObjectName("loadButton")
        self.gridLayout_11.addWidget(self.loadButton, 0, 3, 1, 1)
        self.line_7 = QtWidgets.QFrame(self.centralwidget)
        self.line_7.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_7.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_7.setObjectName("line_7")
        self.gridLayout_11.addWidget(self.line_7, 0, 2, 1, 1)
        self.line_8 = QtWidgets.QFrame(self.centralwidget)
        self.line_8.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_8.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_8.setObjectName("line_8")
        self.gridLayout_11.addWidget(self.line_8, 0, 4, 1, 1)
        self.gridLayout_8.addLayout(self.gridLayout_11, 4, 0, 1, 1)
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setEnabled(True)
        self.tabWidget.setAccessibleName("")
        self.tabWidget.setTabPosition(QtWidgets.QTabWidget.North)
        self.tabWidget.setDocumentMode(True)
        self.tabWidget.setObjectName("tabWidget")
        self.general_tab = QtWidgets.QWidget()
        self.general_tab.setObjectName("general_tab")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.general_tab)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.frame_22 = QtWidgets.QFrame(self.general_tab)
        self.frame_22.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_22.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_22.setObjectName("frame_22")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.frame_22)
        self.verticalLayout_13.setProperty("margin", 0)
        self.verticalLayout_13.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_13.setSpacing(6)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.groupBox_9 = QtWidgets.QGroupBox(self.frame_22)
        self.groupBox_9.setObjectName("groupBox_9")
        self.gridLayout_39 = QtWidgets.QGridLayout(self.groupBox_9)
        self.gridLayout_39.setObjectName("gridLayout_39")
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.browse_output = QtWidgets.QToolButton(self.groupBox_9)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_output.setFont(font)
        self.browse_output.setObjectName("browse_output")
        self.gridLayout_4.addWidget(self.browse_output, 0, 2, 1, 1)
        self.output_dir = QtWidgets.QLineEdit(self.groupBox_9)
        self.output_dir.setMinimumSize(QtCore.QSize(0, 18))
        self.output_dir.setObjectName("output_dir")
        self.gridLayout_4.addWidget(self.output_dir, 0, 1, 1, 1)
        self.label_28 = QtWidgets.QLabel(self.groupBox_9)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label_28.sizePolicy().hasHeightForWidth()
        )
        self.label_28.setSizePolicy(sizePolicy)
        self.label_28.setMinimumSize(QtCore.QSize(85, 0))
        self.label_28.setObjectName("label_28")
        self.gridLayout_4.addWidget(self.label_28, 0, 0, 1, 1)
        self.gridLayout_39.addLayout(self.gridLayout_4, 6, 0, 1, 1)
        self.gridLayout_41 = QtWidgets.QGridLayout()
        self.gridLayout_41.setObjectName("gridLayout_41")
        self.label_281 = QtWidgets.QLabel(self.groupBox_9)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label_281.sizePolicy().hasHeightForWidth()
        )
        self.label_281.setSizePolicy(sizePolicy)
        self.label_281.setMinimumSize(QtCore.QSize(85, 0))
        self.label_281.setObjectName("label_281")
        self.gridLayout_41.addWidget(self.label_281, 0, 0, 1, 1)
        self.input_dir = QtWidgets.QLineEdit(self.groupBox_9)
        self.input_dir.setMinimumSize(QtCore.QSize(0, 18))
        self.input_dir.setObjectName("input_dir")
        self.gridLayout_41.addWidget(self.input_dir, 0, 1, 1, 1)
        self.browse_input = QtWidgets.QToolButton(self.groupBox_9)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_input.setFont(font)
        self.browse_input.setObjectName("browse_input")
        self.gridLayout_41.addWidget(self.browse_input, 0, 2, 1, 1)
        self.gridLayout_39.addLayout(self.gridLayout_41, 5, 0, 1, 1)
        self.groupBox_14 = QtWidgets.QGroupBox(self.groupBox_9)
        self.groupBox_14.setTitle("")
        self.groupBox_14.setObjectName("groupBox_14")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox_14)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.gridLayout_5 = QtWidgets.QGridLayout()
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.browse_code = QtWidgets.QToolButton(self.groupBox_14)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_code.setFont(font)
        self.browse_code.setObjectName("browse_code")
        self.gridLayout_5.addWidget(self.browse_code, 0, 2, 1, 1)
        self.label_code_dir = QtWidgets.QLabel(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label_code_dir.sizePolicy().hasHeightForWidth()
        )
        self.label_code_dir.setSizePolicy(sizePolicy)
        self.label_code_dir.setMinimumSize(QtCore.QSize(71, 0))
        self.label_code_dir.setObjectName("label_code_dir")
        self.gridLayout_5.addWidget(self.label_code_dir, 0, 0, 1, 1)
        self.code_dir = QtWidgets.QLineEdit(self.groupBox_14)
        self.code_dir.setMinimumSize(QtCore.QSize(0, 18))
        self.code_dir.setObjectName("code_dir")
        self.gridLayout_5.addWidget(self.code_dir, 0, 1, 1, 1)
        self.verticalLayout_8.addLayout(self.gridLayout_5)
        self.gridLayout_51 = QtWidgets.QGridLayout()
        self.gridLayout_51.setObjectName("gridLayout_51")
        self.label_chem_dir = QtWidgets.QLabel(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label_chem_dir.sizePolicy().hasHeightForWidth()
        )
        self.label_chem_dir.setSizePolicy(sizePolicy)
        self.label_chem_dir.setMinimumSize(QtCore.QSize(71, 0))
        self.label_chem_dir.setObjectName("label_chem_dir")
        self.gridLayout_51.addWidget(self.label_chem_dir, 0, 0, 1, 1)
        self.browse_chem = QtWidgets.QToolButton(self.groupBox_14)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_chem.setFont(font)
        self.browse_chem.setObjectName("browse_chem")
        self.gridLayout_51.addWidget(self.browse_chem, 0, 2, 1, 1)
        self.chem_dir = QtWidgets.QLineEdit(self.groupBox_14)
        self.chem_dir.setMinimumSize(QtCore.QSize(0, 18))
        self.chem_dir.setObjectName("chem_dir")
        self.gridLayout_51.addWidget(self.chem_dir, 0, 1, 1, 1)
        self.verticalLayout_8.addLayout(self.gridLayout_51)
        self.groupBox_8 = QtWidgets.QGroupBox(self.groupBox_14)
        self.groupBox_8.setTitle("")
        self.groupBox_8.setObjectName("groupBox_8")
        self.verticalLayout_81 = QtWidgets.QVBoxLayout(self.groupBox_8)
        self.verticalLayout_81.setObjectName("verticalLayout_81")
        self.gridLayout_52 = QtWidgets.QGridLayout()
        self.gridLayout_52.setObjectName("gridLayout_52")
        self.browse_chemname = QtWidgets.QToolButton(self.groupBox_8)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_chemname.setFont(font)
        self.browse_chemname.setObjectName("browse_chemname")
        self.gridLayout_52.addWidget(self.browse_chemname, 0, 2, 1, 1)
        self.chemname_dir = QtWidgets.QLineEdit(self.groupBox_8)
        self.chemname_dir.setMinimumSize(QtCore.QSize(0, 18))
        self.chemname_dir.setObjectName("chemname_dir")
        self.gridLayout_52.addWidget(self.chemname_dir, 0, 1, 1, 1)
        self.label_chemname_dir = QtWidgets.QLabel(self.groupBox_8)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label_chemname_dir.sizePolicy().hasHeightForWidth()
        )
        self.label_chemname_dir.setSizePolicy(sizePolicy)
        self.label_chemname_dir.setMinimumSize(QtCore.QSize(57, 0))
        self.label_chemname_dir.setObjectName("label_chemname_dir")
        self.gridLayout_52.addWidget(self.label_chemname_dir, 0, 0, 1, 1)
        self.verticalLayout_81.addLayout(self.gridLayout_52)
        self.verticalLayout_8.addWidget(self.groupBox_8)
        self.gridLayout_9 = QtWidgets.QGridLayout()
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.browse_case = QtWidgets.QToolButton(self.groupBox_14)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_case.setFont(font)
        self.browse_case.setObjectName("browse_case")
        self.gridLayout_9.addWidget(self.browse_case, 0, 2, 1, 1)
        self.case_dir = QtWidgets.QLineEdit(self.groupBox_14)
        self.case_dir.setMinimumSize(QtCore.QSize(0, 18))
        self.case_dir.setObjectName("case_dir")
        self.gridLayout_9.addWidget(self.case_dir, 0, 1, 1, 1)
        self.label_27 = QtWidgets.QLabel(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label_27.sizePolicy().hasHeightForWidth()
        )
        self.label_27.setSizePolicy(sizePolicy)
        self.label_27.setMinimumSize(QtCore.QSize(71, 0))
        self.label_27.setObjectName("label_27")
        self.gridLayout_9.addWidget(self.label_27, 0, 0, 1, 1)
        self.verticalLayout_8.addLayout(self.gridLayout_9)
        self.groupBox_10 = QtWidgets.QGroupBox(self.groupBox_14)
        self.groupBox_10.setTitle("")
        self.groupBox_10.setObjectName("groupBox_10")
        self.verticalLayout_82 = QtWidgets.QVBoxLayout(self.groupBox_10)
        self.verticalLayout_82.setObjectName("verticalLayout_82")
        self.gridLayout_53 = QtWidgets.QGridLayout()
        self.gridLayout_53.setObjectName("gridLayout_53")
        self.browse_casename = QtWidgets.QToolButton(self.groupBox_10)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_casename.setFont(font)
        self.browse_casename.setObjectName("browse_casename")
        self.gridLayout_53.addWidget(self.browse_casename, 0, 2, 1, 1)
        self.casename_dir = QtWidgets.QLineEdit(self.groupBox_10)
        self.casename_dir.setMinimumSize(QtCore.QSize(0, 18))
        self.casename_dir.setObjectName("casename_dir")
        self.gridLayout_53.addWidget(self.casename_dir, 0, 1, 1, 1)
        self.label_casename_dir = QtWidgets.QLabel(self.groupBox_10)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label_casename_dir.sizePolicy().hasHeightForWidth()
        )
        self.label_casename_dir.setSizePolicy(sizePolicy)
        self.label_casename_dir.setMinimumSize(QtCore.QSize(57, 0))
        self.label_casename_dir.setObjectName("label_casename_dir")
        self.gridLayout_53.addWidget(self.label_casename_dir, 0, 0, 1, 1)
        self.verticalLayout_82.addLayout(self.gridLayout_53)
        self.groupBox_13 = QtWidgets.QGroupBox(self.groupBox_10)
        self.groupBox_13.setTitle("")
        self.groupBox_13.setObjectName("groupBox_13")
        self.verticalLayout_83 = QtWidgets.QVBoxLayout(self.groupBox_13)
        self.verticalLayout_83.setObjectName("verticalLayout_83")
        self.gridLayout_54 = QtWidgets.QGridLayout()
        self.gridLayout_54.setObjectName("gridLayout_54")
        self.browse_exe = QtWidgets.QToolButton(self.groupBox_13)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_exe.setFont(font)
        self.browse_exe.setObjectName("browse_exe")
        self.gridLayout_54.addWidget(self.browse_exe, 0, 2, 1, 1)
        self.sosaa_exe = QtWidgets.QLineEdit(self.groupBox_13)
        self.sosaa_exe.setMinimumSize(QtCore.QSize(0, 18))
        self.sosaa_exe.setObjectName("sosaa_exe")
        self.gridLayout_54.addWidget(self.sosaa_exe, 0, 1, 1, 1)
        self.label_sosaa_exe = QtWidgets.QLabel(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label_sosaa_exe.sizePolicy().hasHeightForWidth()
        )
        self.label_sosaa_exe.setSizePolicy(sizePolicy)
        self.label_sosaa_exe.setMinimumSize(QtCore.QSize(43, 0))
        self.label_sosaa_exe.setObjectName("label_sosaa_exe")
        self.gridLayout_54.addWidget(self.label_sosaa_exe, 0, 0, 1, 1)
        self.verticalLayout_83.addLayout(self.gridLayout_54)
        self.verticalLayout_82.addWidget(self.groupBox_13)
        self.verticalLayout_8.addWidget(self.groupBox_10)
        self.gridLayout_39.addWidget(self.groupBox_14, 4, 0, 1, 1)
        self.gridLayout_7 = QtWidgets.QGridLayout()
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.main_dir = QtWidgets.QLineEdit(self.groupBox_9)
        self.main_dir.setMinimumSize(QtCore.QSize(0, 18))
        self.main_dir.setText("")
        self.main_dir.setPlaceholderText("")
        self.main_dir.setObjectName("main_dir")
        self.gridLayout_7.addWidget(self.main_dir, 0, 1, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_9)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.label.sizePolicy().hasHeightForWidth()
        )
        self.label.setSizePolicy(sizePolicy)
        self.label.setMinimumSize(QtCore.QSize(85, 0))
        self.label.setObjectName("label")
        self.gridLayout_7.addWidget(self.label, 0, 0, 1, 1)
        self.browse_main = QtWidgets.QToolButton(self.groupBox_9)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_main.setFont(font)
        self.browse_main.setObjectName("browse_main")
        self.gridLayout_7.addWidget(self.browse_main, 0, 2, 1, 1)
        self.gridLayout_39.addLayout(self.gridLayout_7, 1, 0, 1, 1)
        self.verticalLayout_13.addWidget(self.groupBox_9)
        self.groupBox_2 = QtWidgets.QGroupBox(self.frame_22)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.description = QtWidgets.QPlainTextEdit(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.MinimumExpanding,
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.description.sizePolicy().hasHeightForWidth()
        )
        self.description.setSizePolicy(sizePolicy)
        self.description.setMaximumSize(QtCore.QSize(16777215, 150))
        self.description.setHorizontalScrollBarPolicy(
            QtCore.Qt.ScrollBarAlwaysOff
        )
        self.description.setMaximumBlockCount(0)
        self.description.setObjectName("description")
        self.gridLayout_2.addWidget(self.description, 0, 1, 1, 2)
        self.label_8 = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.gridLayout_2.addWidget(self.label_8, 0, 0, 1, 1)
        self.verticalLayout_13.addWidget(self.groupBox_2)
        spacerItem1 = QtWidgets.QSpacerItem(
            20,
            40,
            QtWidgets.QSizePolicy.Minimum,
            QtWidgets.QSizePolicy.Expanding,
        )
        self.verticalLayout_13.addItem(spacerItem1)
        self.horizontalLayout_9.addWidget(self.frame_22)
        self.tabWidget.addTab(self.general_tab, "")
        self.module_tab = QtWidgets.QWidget()
        self.module_tab.setObjectName("module_tab")
        self.horizontalLayout_91 = QtWidgets.QVBoxLayout(self.module_tab)
        self.horizontalLayout_91.setObjectName("horizontalLayout_91")
        self.horizontalLayout_92 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_92.setObjectName("horizontalLayout_92")
        self.frame_24 = QtWidgets.QFrame(self.module_tab)
        self.frame_24.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_24.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_24.setObjectName("frame_24")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.frame_24)
        self.verticalLayout_11.setProperty("margin", 0)
        self.verticalLayout_11.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_11.setSpacing(6)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.groupBox_16 = QtWidgets.QGroupBox(self.frame_24)
        self.groupBox_16.setObjectName("groupBox_16")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_16)
        self.verticalLayout.setObjectName("verticalLayout")
        self.flag_emis = QtWidgets.QCheckBox(self.groupBox_16)
        self.flag_emis.setChecked(True)
        self.flag_emis.setObjectName("flag_emis")
        self.verticalLayout.addWidget(self.flag_emis)
        self.flag_emis_soil = QtWidgets.QCheckBox(self.groupBox_16)
        self.flag_emis_soil.setEnabled(False)
        self.flag_emis_soil.setChecked(False)
        self.flag_emis_soil.setObjectName("flag_emis_soil")
        self.verticalLayout.addWidget(self.flag_emis_soil)
        self.flag_chem = QtWidgets.QGroupBox(self.groupBox_16)
        self.flag_chem.setCheckable(True)
        self.flag_chem.setObjectName("flag_chem")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.flag_chem)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.flag_mix_chem = QtWidgets.QCheckBox(self.flag_chem)
        self.flag_mix_chem.setChecked(True)
        self.flag_mix_chem.setObjectName("flag_mix_chem")
        self.verticalLayout_2.addWidget(self.flag_mix_chem)
        self.verticalLayout.addWidget(self.flag_chem)
        self.flag_gasdrydep = QtWidgets.QCheckBox(self.groupBox_16)
        self.flag_gasdrydep.setMinimumSize(QtCore.QSize(0, 0))
        self.flag_gasdrydep.setObjectName("flag_gasdrydep")
        self.verticalLayout.addWidget(self.flag_gasdrydep)
        self.flag_aero = QtWidgets.QGroupBox(self.groupBox_16)
        self.flag_aero.setMinimumSize(QtCore.QSize(0, 0))
        self.flag_aero.setFlat(True)
        self.flag_aero.setCheckable(True)
        self.flag_aero.setObjectName("flag_aero")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.flag_aero)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.flag_mix_aero = QtWidgets.QCheckBox(self.flag_aero)
        self.flag_mix_aero.setChecked(True)
        self.flag_mix_aero.setObjectName("flag_mix_aero")
        self.verticalLayout_14.addWidget(self.flag_mix_aero)
        self.aer_nucleation = QtWidgets.QCheckBox(self.flag_aero)
        self.aer_nucleation.setChecked(True)
        self.aer_nucleation.setObjectName("aer_nucleation")
        self.verticalLayout_14.addWidget(self.aer_nucleation)
        self.aer_condensation = QtWidgets.QCheckBox(self.flag_aero)
        self.aer_condensation.setChecked(True)
        self.aer_condensation.setObjectName("aer_condensation")
        self.verticalLayout_14.addWidget(self.aer_condensation)
        self.aer_coagulation = QtWidgets.QCheckBox(self.flag_aero)
        self.aer_coagulation.setChecked(True)
        self.aer_coagulation.setObjectName("aer_coagulation")
        self.verticalLayout_14.addWidget(self.aer_coagulation)
        self.aer_dry_deposition = QtWidgets.QCheckBox(self.flag_aero)
        self.aer_dry_deposition.setChecked(True)
        self.aer_dry_deposition.setObjectName("aer_dry_deposition")
        self.verticalLayout_14.addWidget(self.aer_dry_deposition)
        self.aer_wet_deposition = QtWidgets.QCheckBox(self.flag_aero)
        self.aer_wet_deposition.setEnabled(False)
        self.aer_wet_deposition.setChecked(False)
        self.aer_wet_deposition.setObjectName("aer_wet_deposition")
        self.verticalLayout_14.addWidget(self.aer_wet_deposition)
        self.aer_snow_scavenge = QtWidgets.QCheckBox(self.flag_aero)
        self.aer_snow_scavenge.setObjectName("aer_snow_scavenge")
        self.verticalLayout_14.addWidget(self.aer_snow_scavenge)
        self.verticalLayout.addWidget(self.flag_aero)
        self.verticalLayout_11.addWidget(self.groupBox_16)
        self.horizontalLayout_92.addWidget(self.frame_24)
        self.groupBox_5 = QtWidgets.QGroupBox(self.module_tab)
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.groupBox_5)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.gridLayout_18 = QtWidgets.QGridLayout()
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.label_dt_emis = QtWidgets.QLabel(self.groupBox_5)
        self.label_dt_emis.setObjectName("label_dt_emis")
        self.gridLayout_18.addWidget(self.label_dt_emis, 2, 0, 1, 1)
        self.dt_emis = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.dt_emis.setMaximum(600.0)
        self.dt_emis.setProperty("value", 60.0)
        self.dt_emis.setObjectName("dt_emis")
        self.gridLayout_18.addWidget(self.dt_emis, 2, 1, 1, 1)
        self.dt_aero = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.dt_aero.setMaximum(600.0)
        self.dt_aero.setProperty("value", 60.0)
        self.dt_aero.setObjectName("dt_aero")
        self.gridLayout_18.addWidget(self.dt_aero, 5, 1, 1, 1)
        self.label_dt_obs = QtWidgets.QLabel(self.groupBox_5)
        self.label_dt_obs.setObjectName("label_dt_obs")
        self.gridLayout_18.addWidget(self.label_dt_obs, 0, 0, 1, 1)
        self.dt_chem = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.dt_chem.setMaximum(600.0)
        self.dt_chem.setProperty("value", 60.0)
        self.dt_chem.setObjectName("dt_chem")
        self.gridLayout_18.addWidget(self.dt_chem, 3, 1, 1, 1)
        self.label_dt_chem = QtWidgets.QLabel(self.groupBox_5)
        self.label_dt_chem.setObjectName("label_dt_chem")
        self.gridLayout_18.addWidget(self.label_dt_chem, 3, 0, 1, 1)
        self.label_dt_mete = QtWidgets.QLabel(self.groupBox_5)
        self.label_dt_mete.setObjectName("label_dt_mete")
        self.gridLayout_18.addWidget(self.label_dt_mete, 1, 0, 1, 1)
        self.label_dt_depo = QtWidgets.QLabel(self.groupBox_5)
        self.label_dt_depo.setObjectName("label_dt_depo")
        self.gridLayout_18.addWidget(self.label_dt_depo, 4, 0, 1, 1)
        self.dt_mete = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.dt_mete.setDecimals(2)
        self.dt_mete.setMaximum(100.0)
        self.dt_mete.setProperty("value", 10.0)
        self.dt_mete.setObjectName("dt_mete")
        self.gridLayout_18.addWidget(self.dt_mete, 1, 1, 1, 1)
        self.label_dt_aero = QtWidgets.QLabel(self.groupBox_5)
        self.label_dt_aero.setObjectName("label_dt_aero")
        self.gridLayout_18.addWidget(self.label_dt_aero, 5, 0, 1, 1)
        self.dt_obs = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.dt_obs.setDecimals(2)
        self.dt_obs.setMaximum(6000.0)
        self.dt_obs.setSingleStep(60.0)
        self.dt_obs.setProperty("value", 1800.0)
        self.dt_obs.setObjectName("dt_obs")
        self.gridLayout_18.addWidget(self.dt_obs, 0, 1, 1, 1)
        self.dt_depo = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.dt_depo.setMaximum(600.0)
        self.dt_depo.setProperty("value", 60.0)
        self.dt_depo.setObjectName("dt_depo")
        self.gridLayout_18.addWidget(self.dt_depo, 4, 1, 1, 1)
        self.label_dt_uhma = QtWidgets.QLabel(self.groupBox_5)
        self.label_dt_uhma.setObjectName("label_dt_uhma")
        self.gridLayout_18.addWidget(self.label_dt_uhma, 6, 0, 1, 1)
        self.dt_uhma = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.dt_uhma.setMaximum(100.0)
        self.dt_uhma.setProperty("value", 10.0)
        self.dt_uhma.setObjectName("dt_uhma")
        self.gridLayout_18.addWidget(self.dt_uhma, 6, 1, 1, 1)
        self.verticalLayout_12.addLayout(self.gridLayout_18)
        self.horizontalLayout_92.addWidget(self.groupBox_5)
        self.horizontalLayout_91.addLayout(self.horizontalLayout_92)
        spacerItem2 = QtWidgets.QSpacerItem(
            20,
            40,
            QtWidgets.QSizePolicy.Minimum,
            QtWidgets.QSizePolicy.Expanding,
        )
        self.horizontalLayout_91.addItem(spacerItem2)
        self.tabWidget.addTab(self.module_tab, "")
        self.scenario_tab = QtWidgets.QWidget()
        self.scenario_tab.setObjectName("scenario_tab")
        self.horizontalLayout_93 = QtWidgets.QHBoxLayout(self.scenario_tab)
        self.horizontalLayout_93.setObjectName("horizontalLayout_93")
        self.frame_241 = QtWidgets.QFrame(self.scenario_tab)
        self.frame_241.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_241.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_241.setObjectName("frame_241")
        self.verticalLayout_111 = QtWidgets.QVBoxLayout(self.frame_241)
        self.verticalLayout_111.setProperty("margin", 0)
        self.verticalLayout_111.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_111.setSpacing(6)
        self.verticalLayout_111.setObjectName("verticalLayout_111")
        self.groupBox_51 = QtWidgets.QGroupBox(self.frame_241)
        self.groupBox_51.setObjectName("groupBox_51")
        self.verticalLayout_121 = QtWidgets.QVBoxLayout(self.groupBox_51)
        self.verticalLayout_121.setObjectName("verticalLayout_121")
        self.gridLayout_14 = QtWidgets.QGridLayout()
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.label_14 = QtWidgets.QLabel(self.groupBox_51)
        self.label_14.setObjectName("label_14")
        self.gridLayout_14.addWidget(self.label_14, 0, 0, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox_51)
        self.label_12.setObjectName("label_12")
        self.gridLayout_14.addWidget(self.label_12, 1, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_51)
        self.label_3.setObjectName("label_3")
        self.gridLayout_14.addWidget(self.label_3, 1, 1, 1, 1)
        self.trajectory_duration = QtWidgets.QSpinBox(self.groupBox_51)
        self.trajectory_duration.setMinimum(-10)
        self.trajectory_duration.setMaximum(10)
        self.trajectory_duration.setProperty("value", -7)
        self.trajectory_duration.setObjectName("trajectory_duration")
        self.gridLayout_14.addWidget(self.trajectory_duration, 0, 1, 1, 1)
        self.verticalLayout_121.addLayout(self.gridLayout_14)
        self.verticalLayout_111.addWidget(self.groupBox_51)
        self.groupBox_15 = QtWidgets.QGroupBox(self.frame_241)
        self.groupBox_15.setObjectName("groupBox_15")
        self.verticalLayout1 = QtWidgets.QVBoxLayout(self.groupBox_15)
        self.verticalLayout1.setObjectName("verticalLayout1")
        self.gridLayout_15 = QtWidgets.QGridLayout()
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.start_date = QtWidgets.QDateTimeEdit(self.groupBox_15)
        self.start_date.setObjectName("start_date")
        self.gridLayout_15.addWidget(self.start_date, 0, 3, 1, 1)
        self.aero_start_offset = QtWidgets.QSpinBox(self.groupBox_15)
        self.aero_start_offset.setMaximum(2400)
        self.aero_start_offset.setObjectName("aero_start_offset")
        self.gridLayout_15.addWidget(self.aero_start_offset, 2, 2, 1, 1)
        self.label_31 = QtWidgets.QLabel(self.groupBox_15)
        self.label_31.setObjectName("label_31")
        self.gridLayout_15.addWidget(self.label_31, 0, 0, 1, 1)
        self.end_date = QtWidgets.QDateTimeEdit(self.groupBox_15)
        self.end_date.setObjectName("end_date")
        self.gridLayout_15.addWidget(self.end_date, 3, 3, 1, 1)
        self.aero_start_label = QtWidgets.QLabel(self.groupBox_15)
        self.aero_start_label.setObjectName("aero_start_label")
        self.gridLayout_15.addWidget(self.aero_start_label, 2, 0, 1, 1)
        self.aero_start_date = QtWidgets.QLabel(self.groupBox_15)
        self.aero_start_date.setObjectName("aero_start_date")
        self.gridLayout_15.addWidget(self.aero_start_date, 2, 3, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.groupBox_15)
        self.label_18.setObjectName("label_18")
        self.gridLayout_15.addWidget(self.label_18, 3, 0, 1, 1)
        self.verticalLayout1.addLayout(self.gridLayout_15)
        self.verticalLayout_111.addWidget(self.groupBox_15)
        self.groupBox_11 = QtWidgets.QGroupBox(self.frame_241)
        self.groupBox_11.setEnabled(False)
        self.groupBox_11.setObjectName("groupBox_11")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_11)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.batchRangeDay = QtWidgets.QRadioButton(self.groupBox_11)
        self.batchRangeDay.setChecked(True)
        self.batchRangeDay.setObjectName("batchRangeDay")
        self.gridLayout_6.addWidget(self.batchRangeDay, 0, 0, 1, 1)
        self.batchRangeDayEnd = QtWidgets.QDateEdit(self.groupBox_11)
        self.batchRangeDayEnd.setDate(QtCore.QDate(2020, 1, 5))
        self.batchRangeDayEnd.setObjectName("batchRangeDayEnd")
        self.gridLayout_6.addWidget(self.batchRangeDayEnd, 0, 2, 1, 1)
        self.saveBatch = QtWidgets.QToolButton(self.groupBox_11)
        self.saveBatch.setObjectName("saveBatch")
        self.gridLayout_6.addWidget(self.saveBatch, 3, 1, 1, 1)
        self.batchRangeIndBegin = QtWidgets.QSpinBox(self.groupBox_11)
        self.batchRangeIndBegin.setMinimum(0)
        self.batchRangeIndBegin.setMaximum(999999)
        self.batchRangeIndBegin.setProperty("value", 0)
        self.batchRangeIndBegin.setObjectName("batchRangeIndBegin")
        self.gridLayout_6.addWidget(self.batchRangeIndBegin, 2, 1, 1, 1)
        self.batchFrFile = QtWidgets.QToolButton(self.groupBox_11)
        self.batchFrFile.setObjectName("batchFrFile")
        self.gridLayout_6.addWidget(self.batchFrFile, 3, 2, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout_6.addItem(spacerItem3, 2, 4, 1, 1)
        self.batchRangeDayBegin = QtWidgets.QDateEdit(self.groupBox_11)
        self.batchRangeDayBegin.setDate(QtCore.QDate(2020, 1, 1))
        self.batchRangeDayBegin.setObjectName("batchRangeDayBegin")
        self.gridLayout_6.addWidget(self.batchRangeDayBegin, 0, 1, 1, 1)
        self.batchRangeInd = QtWidgets.QRadioButton(self.groupBox_11)
        self.batchRangeInd.setChecked(False)
        self.batchRangeInd.setObjectName("batchRangeInd")
        self.gridLayout_6.addWidget(self.batchRangeInd, 2, 0, 1, 1)
        self.batchRangeIndEnd = QtWidgets.QSpinBox(self.groupBox_11)
        self.batchRangeIndEnd.setMinimum(0)
        self.batchRangeIndEnd.setMaximum(999999)
        self.batchRangeIndEnd.setProperty("value", 0)
        self.batchRangeIndEnd.setObjectName("batchRangeIndEnd")
        self.gridLayout_6.addWidget(self.batchRangeIndEnd, 2, 2, 1, 1)
        self.createBashFile = QtWidgets.QCheckBox(self.groupBox_11)
        self.createBashFile.setEnabled(False)
        self.createBashFile.setChecked(False)
        self.createBashFile.setObjectName("createBashFile")
        self.gridLayout_6.addWidget(self.createBashFile, 3, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout_6.addItem(spacerItem4, 0, 4, 1, 2)
        self.helpBatch = QtWidgets.QToolButton(self.groupBox_11)
        self.helpBatch.setObjectName("helpBatch")
        self.gridLayout_6.addWidget(self.helpBatch, 3, 3, 1, 1)
        self.verticalLayout_111.addWidget(self.groupBox_11)
        spacerItem5 = QtWidgets.QSpacerItem(
            20,
            40,
            QtWidgets.QSizePolicy.Minimum,
            QtWidgets.QSizePolicy.Expanding,
        )
        self.verticalLayout_111.addItem(spacerItem5)
        self.horizontalLayout_93.addWidget(self.frame_241)
        self.tabWidget.addTab(self.scenario_tab, "")
        self.output_tab = QtWidgets.QWidget()
        self.output_tab.setObjectName("output_tab")
        self.verticalLayout_131 = QtWidgets.QVBoxLayout(self.output_tab)
        self.verticalLayout_131.setSpacing(6)
        self.verticalLayout_131.setObjectName("verticalLayout_131")
        self.groupBox_4 = QtWidgets.QGroupBox(self.output_tab)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.groupBox_6 = QtWidgets.QGroupBox(self.groupBox_4)
        self.groupBox_6.setObjectName("groupBox_6")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.groupBox_6)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.flag_vapor = QtWidgets.QGroupBox(self.groupBox_6)
        self.flag_vapor.setCheckable(True)
        self.flag_vapor.setChecked(False)
        self.flag_vapor.setObjectName("flag_vapor")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.flag_vapor)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.output_list_vap = QtWidgets.QPlainTextEdit(self.flag_vapor)
        self.output_list_vap.setObjectName("output_list_vap")
        self.verticalLayout_7.addWidget(self.output_list_vap)
        self.verticalLayout_6.addWidget(self.flag_vapor)
        self.gridLayout_3.addWidget(self.groupBox_6, 3, 0, 1, 1)
        self.group_output_list_Vd = QtWidgets.QGroupBox(self.groupBox_4)
        self.group_output_list_Vd.setEnabled(False)
        self.group_output_list_Vd.setObjectName("group_output_list_Vd")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(
            self.group_output_list_Vd
        )
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.output_list_Vd = QtWidgets.QPlainTextEdit(
            self.group_output_list_Vd
        )
        self.output_list_Vd.setObjectName("output_list_Vd")
        self.verticalLayout_5.addWidget(self.output_list_Vd)
        self.gridLayout_3.addWidget(self.group_output_list_Vd, 2, 0, 1, 1)
        self.group_output_list_emi = QtWidgets.QGroupBox(self.groupBox_4)
        self.group_output_list_emi.setObjectName("group_output_list_emi")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(
            self.group_output_list_emi
        )
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.output_list_emi = QtWidgets.QPlainTextEdit(
            self.group_output_list_emi
        )
        self.output_list_emi.setObjectName("output_list_emi")
        self.verticalLayout_4.addWidget(self.output_list_emi)
        self.gridLayout_3.addWidget(self.group_output_list_emi, 1, 0, 1, 1)
        self.groupBox_12 = QtWidgets.QGroupBox(self.groupBox_4)
        self.groupBox_12.setObjectName("groupBox_12")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_12)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.output_list_spc = QtWidgets.QPlainTextEdit(self.groupBox_12)
        self.output_list_spc.setObjectName("output_list_spc")
        self.verticalLayout_3.addWidget(self.output_list_spc)
        self.gridLayout_3.addWidget(self.groupBox_12, 0, 0, 1, 1)
        self.verticalLayout_131.addWidget(self.groupBox_4)
        self.tabWidget.addTab(self.output_tab, "")
        self.custom_tab = QtWidgets.QWidget()
        self.custom_tab.setObjectName("custom_tab")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.custom_tab)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.frame_8 = QtWidgets.QFrame(self.custom_tab)
        self.frame_8.setObjectName("frame_8")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout(self.frame_8)
        self.verticalLayout_21.setProperty("margin", 0)
        self.verticalLayout_21.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.groupBox = QtWidgets.QGroupBox(self.frame_8)
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_16 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_16.setVerticalSpacing(3)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.customKey_22 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_22.sizePolicy().hasHeightForWidth()
        )
        self.customKey_22.setSizePolicy(sizePolicy)
        self.customKey_22.setObjectName("customKey_22")
        self.gridLayout_16.addWidget(self.customKey_22, 7, 3, 1, 1)
        self.customVal_14 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_14.sizePolicy().hasHeightForWidth()
        )
        self.customVal_14.setSizePolicy(sizePolicy)
        self.customVal_14.setObjectName("customVal_14")
        self.gridLayout_16.addWidget(self.customVal_14, 14, 1, 1, 1)
        self.customVal_20 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_20.sizePolicy().hasHeightForWidth()
        )
        self.customVal_20.setSizePolicy(sizePolicy)
        self.customVal_20.setObjectName("customVal_20")
        self.gridLayout_16.addWidget(self.customVal_20, 5, 4, 1, 1)
        self.customVal_22 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_22.sizePolicy().hasHeightForWidth()
        )
        self.customVal_22.setSizePolicy(sizePolicy)
        self.customVal_22.setObjectName("customVal_22")
        self.gridLayout_16.addWidget(self.customVal_22, 7, 4, 1, 1)
        self.customKey_3 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_3.sizePolicy().hasHeightForWidth()
        )
        self.customKey_3.setSizePolicy(sizePolicy)
        self.customKey_3.setObjectName("customKey_3")
        self.gridLayout_16.addWidget(self.customKey_3, 3, 0, 1, 1)
        self.customKey_16 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_16.sizePolicy().hasHeightForWidth()
        )
        self.customKey_16.setSizePolicy(sizePolicy)
        self.customKey_16.setObjectName("customKey_16")
        self.gridLayout_16.addWidget(self.customKey_16, 1, 3, 1, 1)
        self.customVal_28 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_28.sizePolicy().hasHeightForWidth()
        )
        self.customVal_28.setSizePolicy(sizePolicy)
        self.customVal_28.setObjectName("customVal_28")
        self.gridLayout_16.addWidget(self.customVal_28, 13, 4, 1, 1)
        self.customVal_1 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_1.sizePolicy().hasHeightForWidth()
        )
        self.customVal_1.setSizePolicy(sizePolicy)
        self.customVal_1.setObjectName("customVal_1")
        self.gridLayout_16.addWidget(self.customVal_1, 1, 1, 1, 1)
        self.customVal_29 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_29.sizePolicy().hasHeightForWidth()
        )
        self.customVal_29.setSizePolicy(sizePolicy)
        self.customVal_29.setObjectName("customVal_29")
        self.gridLayout_16.addWidget(self.customVal_29, 14, 4, 1, 1)
        self.customKey_14 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_14.sizePolicy().hasHeightForWidth()
        )
        self.customKey_14.setSizePolicy(sizePolicy)
        self.customKey_14.setObjectName("customKey_14")
        self.gridLayout_16.addWidget(self.customKey_14, 14, 0, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.groupBox)
        self.label_16.setObjectName("label_16")
        self.gridLayout_16.addWidget(self.label_16, 0, 0, 1, 1)
        self.customKey_28 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_28.sizePolicy().hasHeightForWidth()
        )
        self.customKey_28.setSizePolicy(sizePolicy)
        self.customKey_28.setObjectName("customKey_28")
        self.gridLayout_16.addWidget(self.customKey_28, 13, 3, 1, 1)
        self.customKey_17 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_17.sizePolicy().hasHeightForWidth()
        )
        self.customKey_17.setSizePolicy(sizePolicy)
        self.customKey_17.setObjectName("customKey_17")
        self.gridLayout_16.addWidget(self.customKey_17, 2, 3, 1, 1)
        self.customVal_27 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_27.sizePolicy().hasHeightForWidth()
        )
        self.customVal_27.setSizePolicy(sizePolicy)
        self.customVal_27.setObjectName("customVal_27")
        self.gridLayout_16.addWidget(self.customVal_27, 12, 4, 1, 1)
        self.customKey_21 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_21.sizePolicy().hasHeightForWidth()
        )
        self.customKey_21.setSizePolicy(sizePolicy)
        self.customKey_21.setObjectName("customKey_21")
        self.gridLayout_16.addWidget(self.customKey_21, 6, 3, 1, 1)
        self.customVal_13 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_13.sizePolicy().hasHeightForWidth()
        )
        self.customVal_13.setSizePolicy(sizePolicy)
        self.customVal_13.setObjectName("customVal_13")
        self.gridLayout_16.addWidget(self.customVal_13, 13, 1, 1, 1)
        self.customKey_29 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_29.sizePolicy().hasHeightForWidth()
        )
        self.customKey_29.setSizePolicy(sizePolicy)
        self.customKey_29.setObjectName("customKey_29")
        self.gridLayout_16.addWidget(self.customKey_29, 14, 3, 1, 1)
        self.customKey_6 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_6.sizePolicy().hasHeightForWidth()
        )
        self.customKey_6.setSizePolicy(sizePolicy)
        self.customKey_6.setObjectName("customKey_6")
        self.gridLayout_16.addWidget(self.customKey_6, 6, 0, 1, 1)
        self.customKey_27 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_27.sizePolicy().hasHeightForWidth()
        )
        self.customKey_27.setSizePolicy(sizePolicy)
        self.customKey_27.setObjectName("customKey_27")
        self.gridLayout_16.addWidget(self.customKey_27, 12, 3, 1, 1)
        self.customVal_3 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_3.sizePolicy().hasHeightForWidth()
        )
        self.customVal_3.setSizePolicy(sizePolicy)
        self.customVal_3.setObjectName("customVal_3")
        self.gridLayout_16.addWidget(self.customVal_3, 3, 1, 1, 1)
        self.customVal_18 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_18.sizePolicy().hasHeightForWidth()
        )
        self.customVal_18.setSizePolicy(sizePolicy)
        self.customVal_18.setObjectName("customVal_18")
        self.gridLayout_16.addWidget(self.customVal_18, 3, 4, 1, 1)
        self.customVal_16 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_16.sizePolicy().hasHeightForWidth()
        )
        self.customVal_16.setSizePolicy(sizePolicy)
        self.customVal_16.setObjectName("customVal_16")
        self.gridLayout_16.addWidget(self.customVal_16, 1, 4, 1, 1)
        self.customVal_2 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_2.sizePolicy().hasHeightForWidth()
        )
        self.customVal_2.setSizePolicy(sizePolicy)
        self.customVal_2.setObjectName("customVal_2")
        self.gridLayout_16.addWidget(self.customVal_2, 2, 1, 1, 1)
        self.customKey_2 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_2.sizePolicy().hasHeightForWidth()
        )
        self.customKey_2.setSizePolicy(sizePolicy)
        self.customKey_2.setObjectName("customKey_2")
        self.gridLayout_16.addWidget(self.customKey_2, 2, 0, 1, 1)
        self.customKey_26 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_26.sizePolicy().hasHeightForWidth()
        )
        self.customKey_26.setSizePolicy(sizePolicy)
        self.customKey_26.setObjectName("customKey_26")
        self.gridLayout_16.addWidget(self.customKey_26, 11, 3, 1, 1)
        self.customVal_17 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_17.sizePolicy().hasHeightForWidth()
        )
        self.customVal_17.setSizePolicy(sizePolicy)
        self.customVal_17.setObjectName("customVal_17")
        self.gridLayout_16.addWidget(self.customVal_17, 2, 4, 1, 1)
        self.customVal_30 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_30.sizePolicy().hasHeightForWidth()
        )
        self.customVal_30.setSizePolicy(sizePolicy)
        self.customVal_30.setObjectName("customVal_30")
        self.gridLayout_16.addWidget(self.customVal_30, 15, 4, 1, 1)
        self.customKey_15 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_15.sizePolicy().hasHeightForWidth()
        )
        self.customKey_15.setSizePolicy(sizePolicy)
        self.customKey_15.setObjectName("customKey_15")
        self.gridLayout_16.addWidget(self.customKey_15, 15, 0, 1, 1)
        self.customKey_13 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_13.sizePolicy().hasHeightForWidth()
        )
        self.customKey_13.setSizePolicy(sizePolicy)
        self.customKey_13.setObjectName("customKey_13")
        self.gridLayout_16.addWidget(self.customKey_13, 13, 0, 1, 1)
        self.customKey_8 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_8.sizePolicy().hasHeightForWidth()
        )
        self.customKey_8.setSizePolicy(sizePolicy)
        self.customKey_8.setObjectName("customKey_8")
        self.gridLayout_16.addWidget(self.customKey_8, 8, 0, 1, 1)
        self.customVal_23 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_23.sizePolicy().hasHeightForWidth()
        )
        self.customVal_23.setSizePolicy(sizePolicy)
        self.customVal_23.setObjectName("customVal_23")
        self.gridLayout_16.addWidget(self.customVal_23, 8, 4, 1, 1)
        self.customKey_20 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_20.sizePolicy().hasHeightForWidth()
        )
        self.customKey_20.setSizePolicy(sizePolicy)
        self.customKey_20.setObjectName("customKey_20")
        self.gridLayout_16.addWidget(self.customKey_20, 5, 3, 1, 1)
        self.customKey_19 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_19.sizePolicy().hasHeightForWidth()
        )
        self.customKey_19.setSizePolicy(sizePolicy)
        self.customKey_19.setObjectName("customKey_19")
        self.gridLayout_16.addWidget(self.customKey_19, 4, 3, 1, 1)
        self.customKey_5 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_5.sizePolicy().hasHeightForWidth()
        )
        self.customKey_5.setSizePolicy(sizePolicy)
        self.customKey_5.setObjectName("customKey_5")
        self.gridLayout_16.addWidget(self.customKey_5, 5, 0, 1, 1)
        self.customVal_9 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_9.sizePolicy().hasHeightForWidth()
        )
        self.customVal_9.setSizePolicy(sizePolicy)
        self.customVal_9.setObjectName("customVal_9")
        self.gridLayout_16.addWidget(self.customVal_9, 9, 1, 1, 1)
        self.customKey_12 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_12.sizePolicy().hasHeightForWidth()
        )
        self.customKey_12.setSizePolicy(sizePolicy)
        self.customKey_12.setObjectName("customKey_12")
        self.gridLayout_16.addWidget(self.customKey_12, 12, 0, 1, 1)
        self.label_24 = QtWidgets.QLabel(self.groupBox)
        self.label_24.setObjectName("label_24")
        self.gridLayout_16.addWidget(self.label_24, 0, 1, 1, 1)
        self.label_30 = QtWidgets.QLabel(self.groupBox)
        self.label_30.setObjectName("label_30")
        self.gridLayout_16.addWidget(self.label_30, 0, 3, 1, 1)
        self.customVal_5 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_5.sizePolicy().hasHeightForWidth()
        )
        self.customVal_5.setSizePolicy(sizePolicy)
        self.customVal_5.setObjectName("customVal_5")
        self.gridLayout_16.addWidget(self.customVal_5, 5, 1, 1, 1)
        self.customKey_23 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_23.sizePolicy().hasHeightForWidth()
        )
        self.customKey_23.setSizePolicy(sizePolicy)
        self.customKey_23.setObjectName("customKey_23")
        self.gridLayout_16.addWidget(self.customKey_23, 8, 3, 1, 1)
        self.customVal_15 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_15.sizePolicy().hasHeightForWidth()
        )
        self.customVal_15.setSizePolicy(sizePolicy)
        self.customVal_15.setObjectName("customVal_15")
        self.gridLayout_16.addWidget(self.customVal_15, 15, 1, 1, 1)
        self.customKey_24 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_24.sizePolicy().hasHeightForWidth()
        )
        self.customKey_24.setSizePolicy(sizePolicy)
        self.customKey_24.setObjectName("customKey_24")
        self.gridLayout_16.addWidget(self.customKey_24, 9, 3, 1, 1)
        self.customKey_1 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_1.sizePolicy().hasHeightForWidth()
        )
        self.customKey_1.setSizePolicy(sizePolicy)
        self.customKey_1.setObjectName("customKey_1")
        self.gridLayout_16.addWidget(self.customKey_1, 1, 0, 1, 1)
        self.customVal_12 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_12.sizePolicy().hasHeightForWidth()
        )
        self.customVal_12.setSizePolicy(sizePolicy)
        self.customVal_12.setObjectName("customVal_12")
        self.gridLayout_16.addWidget(self.customVal_12, 12, 1, 1, 1)
        self.customVal_24 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_24.sizePolicy().hasHeightForWidth()
        )
        self.customVal_24.setSizePolicy(sizePolicy)
        self.customVal_24.setObjectName("customVal_24")
        self.gridLayout_16.addWidget(self.customVal_24, 9, 4, 1, 1)
        self.customVal_6 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_6.sizePolicy().hasHeightForWidth()
        )
        self.customVal_6.setSizePolicy(sizePolicy)
        self.customVal_6.setObjectName("customVal_6")
        self.gridLayout_16.addWidget(self.customVal_6, 6, 1, 1, 1)
        self.customVal_7 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_7.sizePolicy().hasHeightForWidth()
        )
        self.customVal_7.setSizePolicy(sizePolicy)
        self.customVal_7.setObjectName("customVal_7")
        self.gridLayout_16.addWidget(self.customVal_7, 7, 1, 1, 1)
        self.customVal_25 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_25.sizePolicy().hasHeightForWidth()
        )
        self.customVal_25.setSizePolicy(sizePolicy)
        self.customVal_25.setObjectName("customVal_25")
        self.gridLayout_16.addWidget(self.customVal_25, 10, 4, 1, 1)
        self.customKey_30 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_30.sizePolicy().hasHeightForWidth()
        )
        self.customKey_30.setSizePolicy(sizePolicy)
        self.customKey_30.setObjectName("customKey_30")
        self.gridLayout_16.addWidget(self.customKey_30, 15, 3, 1, 1)
        self.customKey_11 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_11.sizePolicy().hasHeightForWidth()
        )
        self.customKey_11.setSizePolicy(sizePolicy)
        self.customKey_11.setObjectName("customKey_11")
        self.gridLayout_16.addWidget(self.customKey_11, 11, 0, 1, 1)
        self.customVal_4 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_4.sizePolicy().hasHeightForWidth()
        )
        self.customVal_4.setSizePolicy(sizePolicy)
        self.customVal_4.setObjectName("customVal_4")
        self.gridLayout_16.addWidget(self.customVal_4, 4, 1, 1, 1)
        self.label_29 = QtWidgets.QLabel(self.groupBox)
        self.label_29.setObjectName("label_29")
        self.gridLayout_16.addWidget(self.label_29, 0, 4, 1, 1)
        self.customVal_11 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_11.sizePolicy().hasHeightForWidth()
        )
        self.customVal_11.setSizePolicy(sizePolicy)
        self.customVal_11.setObjectName("customVal_11")
        self.gridLayout_16.addWidget(self.customVal_11, 11, 1, 1, 1)
        self.customKey_18 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_18.sizePolicy().hasHeightForWidth()
        )
        self.customKey_18.setSizePolicy(sizePolicy)
        self.customKey_18.setObjectName("customKey_18")
        self.gridLayout_16.addWidget(self.customKey_18, 3, 3, 1, 1)
        self.customKey_7 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_7.sizePolicy().hasHeightForWidth()
        )
        self.customKey_7.setSizePolicy(sizePolicy)
        self.customKey_7.setObjectName("customKey_7")
        self.gridLayout_16.addWidget(self.customKey_7, 7, 0, 1, 1)
        self.customKey_10 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_10.sizePolicy().hasHeightForWidth()
        )
        self.customKey_10.setSizePolicy(sizePolicy)
        self.customKey_10.setObjectName("customKey_10")
        self.gridLayout_16.addWidget(self.customKey_10, 10, 0, 1, 1)
        self.customVal_10 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_10.sizePolicy().hasHeightForWidth()
        )
        self.customVal_10.setSizePolicy(sizePolicy)
        self.customVal_10.setObjectName("customVal_10")
        self.gridLayout_16.addWidget(self.customVal_10, 10, 1, 1, 1)
        self.customKey_25 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_25.sizePolicy().hasHeightForWidth()
        )
        self.customKey_25.setSizePolicy(sizePolicy)
        self.customKey_25.setObjectName("customKey_25")
        self.gridLayout_16.addWidget(self.customKey_25, 10, 3, 1, 1)
        self.customVal_21 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_21.sizePolicy().hasHeightForWidth()
        )
        self.customVal_21.setSizePolicy(sizePolicy)
        self.customVal_21.setObjectName("customVal_21")
        self.gridLayout_16.addWidget(self.customVal_21, 6, 4, 1, 1)
        self.customKey_9 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_9.sizePolicy().hasHeightForWidth()
        )
        self.customKey_9.setSizePolicy(sizePolicy)
        self.customKey_9.setObjectName("customKey_9")
        self.gridLayout_16.addWidget(self.customKey_9, 9, 0, 1, 1)
        self.customVal_19 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_19.sizePolicy().hasHeightForWidth()
        )
        self.customVal_19.setSizePolicy(sizePolicy)
        self.customVal_19.setObjectName("customVal_19")
        self.gridLayout_16.addWidget(self.customVal_19, 4, 4, 1, 1)
        self.customVal_8 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_8.sizePolicy().hasHeightForWidth()
        )
        self.customVal_8.setSizePolicy(sizePolicy)
        self.customVal_8.setObjectName("customVal_8")
        self.gridLayout_16.addWidget(self.customVal_8, 8, 1, 1, 1)
        self.customVal_26 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customVal_26.sizePolicy().hasHeightForWidth()
        )
        self.customVal_26.setSizePolicy(sizePolicy)
        self.customVal_26.setObjectName("customVal_26")
        self.gridLayout_16.addWidget(self.customVal_26, 11, 4, 1, 1)
        self.line = QtWidgets.QFrame(self.groupBox)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout_16.addWidget(self.line, 0, 2, 17, 1)
        self.customKey_4 = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.customKey_4.sizePolicy().hasHeightForWidth()
        )
        self.customKey_4.setSizePolicy(sizePolicy)
        self.customKey_4.setObjectName("customKey_4")
        self.gridLayout_16.addWidget(self.customKey_4, 4, 0, 1, 1)
        self.verticalLayout_21.addWidget(self.groupBox)
        self.horizontalLayout_18.addWidget(self.frame_8)
        self.groupBox_7 = QtWidgets.QGroupBox(self.custom_tab)
        self.groupBox_7.setObjectName("groupBox_7")
        self.gridLayout_17 = QtWidgets.QGridLayout(self.groupBox_7)
        self.gridLayout_17.setObjectName("gridLayout_17")
        self.rawEdit = QtWidgets.QPlainTextEdit(self.groupBox_7)
        self.rawEdit.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.rawEdit.setObjectName("rawEdit")
        self.gridLayout_17.addWidget(self.rawEdit, 0, 0, 1, 1)
        self.horizontalLayout_18.addWidget(self.groupBox_7)
        self.tabWidget.addTab(self.custom_tab, "")
        self.initfile_tab = QtWidgets.QWidget()
        self.initfile_tab.setObjectName("initfile_tab")
        self.horizontalLayout_181 = QtWidgets.QVBoxLayout(self.initfile_tab)
        self.horizontalLayout_181.setObjectName("horizontalLayout_181")
        self.frame_301 = QtWidgets.QFrame(self.initfile_tab)
        self.frame_301.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_301.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_301.setObjectName("frame_301")
        self.horizontalLayout_231 = QtWidgets.QHBoxLayout(self.frame_301)
        self.horizontalLayout_231.setProperty("margin", 0)
        self.horizontalLayout_231.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_231.setSpacing(0)
        self.horizontalLayout_231.setObjectName("horizontalLayout_231")
        self.label_131 = QtWidgets.QLabel(self.frame_301)
        self.label_131.setObjectName("label_131")
        self.horizontalLayout_231.addWidget(self.label_131)
        self.horizontalLayout_181.addWidget(self.frame_301)
        self.currentInitFileContent = QtWidgets.QPlainTextEdit(
            self.initfile_tab
        )
        self.currentInitFileContent.setUndoRedoEnabled(False)
        self.currentInitFileContent.setLineWrapMode(
            QtWidgets.QPlainTextEdit.NoWrap
        )
        self.currentInitFileContent.setReadOnly(True)
        self.currentInitFileContent.setObjectName("currentInitFileContent")
        self.horizontalLayout_181.addWidget(self.currentInitFileContent)
        self.tabWidget.addTab(self.initfile_tab, "")
        self.sosaa_tab = QtWidgets.QWidget()
        self.sosaa_tab.setObjectName("sosaa_tab")
        self.horizontalLayout_94 = QtWidgets.QVBoxLayout(self.sosaa_tab)
        self.horizontalLayout_94.setObjectName("horizontalLayout_94")
        self.sosaa_subtab = QtWidgets.QTabWidget(self.sosaa_tab)
        self.sosaa_subtab.setObjectName("sosaa_subtab")
        self.compile_tab = QtWidgets.QWidget()
        self.compile_tab.setObjectName("compile_tab")
        self.horizontalLayout_95 = QtWidgets.QVBoxLayout(self.compile_tab)
        self.horizontalLayout_95.setObjectName("horizontalLayout_95")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        spacerItem6 = QtWidgets.QSpacerItem(
            20,
            40,
            QtWidgets.QSizePolicy.Minimum,
            QtWidgets.QSizePolicy.Expanding,
        )
        self.gridLayout.addItem(spacerItem6, 2, 1, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout.addItem(spacerItem7, 1, 0, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout.addItem(spacerItem8, 1, 2, 1, 1)
        self.terminal_compile = QtWidgets.QWidget(self.compile_tab)
        self.terminal_compile.setMinimumSize(QtCore.QSize(640, 480))
        self.terminal_compile.setMaximumSize(QtCore.QSize(640, 480))
        self.terminal_compile.setObjectName("terminal_compile")
        self.gridLayout.addWidget(self.terminal_compile, 1, 1, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(
            20,
            40,
            QtWidgets.QSizePolicy.Minimum,
            QtWidgets.QSizePolicy.Expanding,
        )
        self.gridLayout.addItem(spacerItem9, 0, 1, 1, 1)
        self.horizontalLayout_95.addLayout(self.gridLayout)
        self.horizontalLayout_4 = QtWidgets.QGridLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.compile_stop = QtWidgets.QPushButton(self.compile_tab)
        self.compile_stop.setObjectName("compile_stop")
        self.horizontalLayout_4.addWidget(self.compile_stop, 0, 1, 1, 1)
        self.compile_start = QtWidgets.QPushButton(self.compile_tab)
        self.compile_start.setObjectName("compile_start")
        self.horizontalLayout_4.addWidget(self.compile_start, 0, 0, 1, 1)
        self.compile_clean = QtWidgets.QPushButton(self.compile_tab)
        self.compile_clean.setObjectName("compile_clean")
        self.horizontalLayout_4.addWidget(self.compile_clean, 1, 0, 1, 1)
        self.compile_cleanchem = QtWidgets.QPushButton(self.compile_tab)
        self.compile_cleanchem.setObjectName("compile_cleanchem")
        self.horizontalLayout_4.addWidget(self.compile_cleanchem, 1, 1, 1, 1)
        self.horizontalLayout_95.addLayout(self.horizontalLayout_4)
        self.sosaa_subtab.addTab(self.compile_tab, "")
        self.run_tab = QtWidgets.QWidget()
        self.run_tab.setObjectName("run_tab")
        self.horizontalLayout_96 = QtWidgets.QVBoxLayout(self.run_tab)
        self.horizontalLayout_96.setObjectName("horizontalLayout_96")
        self.groupBox_3 = QtWidgets.QGroupBox(self.run_tab)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_122 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_122.setObjectName("verticalLayout_122")
        self.gridLayout_141 = QtWidgets.QGridLayout()
        self.gridLayout_141.setObjectName("gridLayout_141")
        self.launch_cmd = QtWidgets.QLineEdit(self.groupBox_3)
        self.launch_cmd.setObjectName("launch_cmd")
        self.gridLayout_141.addWidget(self.launch_cmd, 0, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_3)
        self.label_4.setObjectName("label_4")
        self.gridLayout_141.addWidget(self.label_4, 0, 0, 1, 1)
        self.flag_debug = QtWidgets.QCheckBox(self.groupBox_3)
        self.flag_debug.setObjectName("flag_debug")
        self.gridLayout_141.addWidget(self.flag_debug, 1, 0, 1, 2)
        self.verticalLayout_122.addLayout(self.gridLayout_141)
        self.horizontalLayout_96.addWidget(self.groupBox_3)
        self.gridLayout1 = QtWidgets.QGridLayout()
        self.gridLayout1.setObjectName("gridLayout1")
        spacerItem10 = QtWidgets.QSpacerItem(
            20,
            40,
            QtWidgets.QSizePolicy.Minimum,
            QtWidgets.QSizePolicy.Expanding,
        )
        self.gridLayout1.addItem(spacerItem10, 2, 1, 1, 1)
        self.terminal_run = QtWidgets.QWidget(self.run_tab)
        self.terminal_run.setMinimumSize(QtCore.QSize(640, 480))
        self.terminal_run.setMaximumSize(QtCore.QSize(640, 480))
        self.terminal_run.setObjectName("terminal_run")
        self.gridLayout1.addWidget(self.terminal_run, 1, 1, 1, 1)
        spacerItem11 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout1.addItem(spacerItem11, 1, 0, 1, 1)
        spacerItem12 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout1.addItem(spacerItem12, 1, 2, 1, 1)
        spacerItem13 = QtWidgets.QSpacerItem(
            20,
            40,
            QtWidgets.QSizePolicy.Minimum,
            QtWidgets.QSizePolicy.Expanding,
        )
        self.gridLayout1.addItem(spacerItem13, 0, 1, 1, 1)
        self.horizontalLayout_96.addLayout(self.gridLayout1)
        self.horizontalLayout_41 = QtWidgets.QGridLayout()
        self.horizontalLayout_41.setObjectName("horizontalLayout_41")
        self.model_stop = QtWidgets.QPushButton(self.run_tab)
        self.model_stop.setObjectName("model_stop")
        self.horizontalLayout_41.addWidget(self.model_stop, 0, 1, 1, 1)
        self.model_start = QtWidgets.QPushButton(self.run_tab)
        self.model_start.setObjectName("model_start")
        self.horizontalLayout_41.addWidget(self.model_start, 0, 0, 1, 1)
        self.horizontalLayout_96.addLayout(self.horizontalLayout_41)
        self.sosaa_subtab.addTab(self.run_tab, "")
        self.horizontalLayout_94.addWidget(self.sosaa_subtab)
        self.tabWidget.addTab(self.sosaa_tab, "")
        self.rsm_tab = QtWidgets.QWidget()
        self.rsm_tab.setObjectName("rsm_tab")
        self.horizontalLayout_97 = QtWidgets.QVBoxLayout(self.rsm_tab)
        self.horizontalLayout_97.setObjectName("horizontalLayout_97")
        self.rsm_subtab = QtWidgets.QTabWidget(self.rsm_tab)
        self.rsm_subtab.setObjectName("rsm_subtab")
        self.rsm_build_tab = QtWidgets.QWidget()
        self.rsm_build_tab.setObjectName("rsm_build_tab")
        self.horizontalLayout_98 = QtWidgets.QVBoxLayout(self.rsm_build_tab)
        self.horizontalLayout_98.setObjectName("horizontalLayout_98")
        self.groupBox_17 = QtWidgets.QGroupBox(self.rsm_build_tab)
        self.groupBox_17.setObjectName("groupBox_17")
        self.gridLayout2 = QtWidgets.QGridLayout(self.groupBox_17)
        self.gridLayout2.setObjectName("gridLayout2")
        self.rsm_forest = QtWidgets.QSpinBox(self.groupBox_17)
        self.rsm_forest.setMinimum(1)
        self.rsm_forest.setProperty("value", 16)
        self.rsm_forest.setObjectName("rsm_forest")
        self.gridLayout2.addWidget(self.rsm_forest, 2, 2, 1, 2)
        self.label_2 = QtWidgets.QLabel(self.groupBox_17)
        self.label_2.setObjectName("label_2")
        self.gridLayout2.addWidget(self.label_2, 0, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_17)
        self.label_6.setObjectName("label_6")
        self.gridLayout2.addWidget(self.label_6, 1, 0, 1, 1)
        self.rsm_path = QtWidgets.QLineEdit(self.groupBox_17)
        self.rsm_path.setObjectName("rsm_path")
        self.gridLayout2.addWidget(self.rsm_path, 0, 2, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_17)
        self.label_5.setObjectName("label_5")
        self.gridLayout2.addWidget(self.label_5, 2, 0, 1, 1)
        self.browse_rsm = QtWidgets.QToolButton(self.groupBox_17)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_rsm.setFont(font)
        self.browse_rsm.setObjectName("browse_rsm")
        self.gridLayout2.addWidget(self.browse_rsm, 0, 3, 1, 1)
        self.rsm_train_seed = QtWidgets.QLineEdit(self.groupBox_17)
        self.rsm_train_seed.setObjectName("rsm_train_seed")
        self.gridLayout2.addWidget(self.rsm_train_seed, 1, 2, 1, 2)
        self.label_9 = QtWidgets.QLabel(self.groupBox_17)
        self.label_9.setObjectName("label_9")
        self.gridLayout2.addWidget(self.label_9, 3, 0, 1, 1)
        self.rsm_train_samples = QtWidgets.QSpinBox(self.groupBox_17)
        self.rsm_train_samples.setMinimum(1)
        self.rsm_train_samples.setProperty("value", 1)
        self.rsm_train_samples.setObjectName("rsm_train_samples")
        self.gridLayout2.addWidget(self.rsm_train_samples, 3, 2, 1, 2)
        self.horizontalLayout_98.addWidget(self.groupBox_17)
        self.horizontalLayout_42 = QtWidgets.QGridLayout()
        self.horizontalLayout_42.setObjectName("horizontalLayout_42")
        self.rsm_build_progress_minor = QtWidgets.QProgressBar(
            self.rsm_build_tab
        )
        self.rsm_build_progress_minor.setProperty("value", 0)
        self.rsm_build_progress_minor.setObjectName("rsm_build_progress_minor")
        self.horizontalLayout_42.addWidget(
            self.rsm_build_progress_minor, 2, 0, 1, 1
        )
        self.rsm_build_progress_major = QtWidgets.QProgressBar(
            self.rsm_build_tab
        )
        self.rsm_build_progress_major.setProperty("value", 0)
        self.rsm_build_progress_major.setObjectName("rsm_build_progress_major")
        self.horizontalLayout_42.addWidget(
            self.rsm_build_progress_major, 1, 0, 1, 1
        )
        self.rsm_build = QtWidgets.QPushButton(self.rsm_build_tab)
        self.rsm_build.setObjectName("rsm_build")
        self.horizontalLayout_42.addWidget(self.rsm_build, 0, 0, 1, 1)
        self.rsm_load = QtWidgets.QPushButton(self.rsm_build_tab)
        self.rsm_load.setObjectName("rsm_load")
        self.horizontalLayout_42.addWidget(self.rsm_load, 3, 0, 1, 1)
        self.horizontalLayout_98.addLayout(self.horizontalLayout_42)
        self.groupBox_18 = QtWidgets.QGroupBox(self.rsm_build_tab)
        self.groupBox_18.setObjectName("groupBox_18")
        self.gridLayout3 = QtWidgets.QGridLayout(self.groupBox_18)
        self.gridLayout3.setObjectName("gridLayout3")
        self.label_21 = QtWidgets.QLabel(self.groupBox_18)
        self.label_21.setObjectName("label_21")
        self.gridLayout3.addWidget(self.label_21, 0, 0, 1, 1)
        self.label_61 = QtWidgets.QLabel(self.groupBox_18)
        self.label_61.setObjectName("label_61")
        self.gridLayout3.addWidget(self.label_61, 1, 0, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.groupBox_18)
        self.label_11.setObjectName("label_11")
        self.gridLayout3.addWidget(self.label_11, 0, 3, 1, 1)
        self.line_4 = QtWidgets.QFrame(self.groupBox_18)
        self.line_4.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.gridLayout3.addWidget(self.line_4, 0, 2, 4, 1)
        self.label_51 = QtWidgets.QLabel(self.groupBox_18)
        self.label_51.setObjectName("label_51")
        self.gridLayout3.addWidget(self.label_51, 2, 0, 1, 1)
        self.rsm_train_mse = QtWidgets.QLabel(self.groupBox_18)
        self.rsm_train_mse.setText("")
        self.rsm_train_mse.setAlignment(
            QtCore.Qt.AlignRight
            | QtCore.Qt.AlignTrailing
            | QtCore.Qt.AlignVCenter
        )
        self.rsm_train_mse.setObjectName("rsm_train_mse")
        self.gridLayout3.addWidget(self.rsm_train_mse, 0, 1, 1, 1)
        self.rsm_test_mse = QtWidgets.QLabel(self.groupBox_18)
        self.rsm_test_mse.setText("")
        self.rsm_test_mse.setAlignment(
            QtCore.Qt.AlignRight
            | QtCore.Qt.AlignTrailing
            | QtCore.Qt.AlignVCenter
        )
        self.rsm_test_mse.setObjectName("rsm_test_mse")
        self.gridLayout3.addWidget(self.rsm_test_mse, 0, 4, 1, 1)
        self.rsm_train_mae = QtWidgets.QLabel(self.groupBox_18)
        self.rsm_train_mae.setText("")
        self.rsm_train_mae.setAlignment(
            QtCore.Qt.AlignRight
            | QtCore.Qt.AlignTrailing
            | QtCore.Qt.AlignVCenter
        )
        self.rsm_train_mae.setObjectName("rsm_train_mae")
        self.gridLayout3.addWidget(self.rsm_train_mae, 1, 1, 1, 1)
        self.label_19 = QtWidgets.QLabel(self.groupBox_18)
        self.label_19.setObjectName("label_19")
        self.gridLayout3.addWidget(self.label_19, 1, 3, 1, 1)
        self.rsm_test_mae = QtWidgets.QLabel(self.groupBox_18)
        self.rsm_test_mae.setText("")
        self.rsm_test_mae.setAlignment(
            QtCore.Qt.AlignRight
            | QtCore.Qt.AlignTrailing
            | QtCore.Qt.AlignVCenter
        )
        self.rsm_test_mae.setObjectName("rsm_test_mae")
        self.gridLayout3.addWidget(self.rsm_test_mae, 1, 4, 1, 1)
        self.rsm_train_r2 = QtWidgets.QLabel(self.groupBox_18)
        self.rsm_train_r2.setText("")
        self.rsm_train_r2.setAlignment(
            QtCore.Qt.AlignRight
            | QtCore.Qt.AlignTrailing
            | QtCore.Qt.AlignVCenter
        )
        self.rsm_train_r2.setObjectName("rsm_train_r2")
        self.gridLayout3.addWidget(self.rsm_train_r2, 2, 1, 1, 1)
        self.label_23 = QtWidgets.QLabel(self.groupBox_18)
        self.label_23.setObjectName("label_23")
        self.gridLayout3.addWidget(self.label_23, 2, 3, 1, 1)
        self.rsm_test_r2 = QtWidgets.QLabel(self.groupBox_18)
        self.rsm_test_r2.setText("")
        self.rsm_test_r2.setAlignment(
            QtCore.Qt.AlignRight
            | QtCore.Qt.AlignTrailing
            | QtCore.Qt.AlignVCenter
        )
        self.rsm_test_r2.setObjectName("rsm_test_r2")
        self.gridLayout3.addWidget(self.rsm_test_r2, 2, 4, 1, 1)
        self.label_231 = QtWidgets.QLabel(self.groupBox_18)
        self.label_231.setObjectName("label_231")
        self.gridLayout3.addWidget(self.label_231, 3, 3, 1, 1)
        self.rsm_test_rmsce = QtWidgets.QLabel(self.groupBox_18)
        self.rsm_test_rmsce.setText("")
        self.rsm_test_rmsce.setAlignment(
            QtCore.Qt.AlignRight
            | QtCore.Qt.AlignTrailing
            | QtCore.Qt.AlignVCenter
        )
        self.rsm_test_rmsce.setObjectName("rsm_test_rmsce")
        self.gridLayout3.addWidget(self.rsm_test_rmsce, 3, 4, 1, 1)
        self.label_232 = QtWidgets.QLabel(self.groupBox_18)
        self.label_232.setObjectName("label_232")
        self.gridLayout3.addWidget(self.label_232, 3, 0, 1, 1)
        self.rsm_train_rmsce = QtWidgets.QLabel(self.groupBox_18)
        self.rsm_train_rmsce.setText("")
        self.rsm_train_rmsce.setAlignment(
            QtCore.Qt.AlignRight
            | QtCore.Qt.AlignTrailing
            | QtCore.Qt.AlignVCenter
        )
        self.rsm_train_rmsce.setObjectName("rsm_train_rmsce")
        self.gridLayout3.addWidget(self.rsm_train_rmsce, 3, 1, 1, 1)
        self.horizontalLayout_98.addWidget(self.groupBox_18)
        self.rsm_subtab.addTab(self.rsm_build_tab, "")
        self.rsm_predict_tab = QtWidgets.QWidget()
        self.rsm_predict_tab.setObjectName("rsm_predict_tab")
        self.horizontalLayout_99 = QtWidgets.QVBoxLayout(self.rsm_predict_tab)
        self.horizontalLayout_99.setObjectName("horizontalLayout_99")
        self.groupBox_31 = QtWidgets.QGroupBox(self.rsm_predict_tab)
        self.groupBox_31.setObjectName("groupBox_31")
        self.gridLayout4 = QtWidgets.QGridLayout(self.groupBox_31)
        self.gridLayout4.setObjectName("gridLayout4")
        self.label_22 = QtWidgets.QLabel(self.groupBox_31)
        self.label_22.setObjectName("label_22")
        self.gridLayout4.addWidget(self.label_22, 0, 0, 1, 1)
        self.label_52 = QtWidgets.QLabel(self.groupBox_31)
        self.label_52.setObjectName("label_52")
        self.gridLayout4.addWidget(self.label_52, 2, 0, 1, 1)
        self.rsm_output = QtWidgets.QLineEdit(self.groupBox_31)
        self.rsm_output.setObjectName("rsm_output")
        self.gridLayout4.addWidget(self.rsm_output, 0, 1, 1, 1)
        self.browse_rsm_output = QtWidgets.QToolButton(self.groupBox_31)
        font = QtGui.QFont()
        font.setBold(False)
        self.browse_rsm_output.setFont(font)
        self.browse_rsm_output.setObjectName("browse_rsm_output")
        self.gridLayout4.addWidget(self.browse_rsm_output, 0, 2, 1, 1)
        self.label_62 = QtWidgets.QLabel(self.groupBox_31)
        self.label_62.setObjectName("label_62")
        self.gridLayout4.addWidget(self.label_62, 1, 0, 1, 1)
        self.rsm_predict_seed = QtWidgets.QLineEdit(self.groupBox_31)
        self.rsm_predict_seed.setObjectName("rsm_predict_seed")
        self.gridLayout4.addWidget(self.rsm_predict_seed, 1, 1, 1, 2)
        self.rsm_predict_samples = QtWidgets.QSpinBox(self.groupBox_31)
        self.rsm_predict_samples.setMinimum(1)
        self.rsm_predict_samples.setProperty("value", 1)
        self.rsm_predict_samples.setObjectName("rsm_predict_samples")
        self.gridLayout4.addWidget(self.rsm_predict_samples, 2, 1, 1, 2)
        self.groupBox_19 = QtWidgets.QGroupBox(self.groupBox_31)
        self.groupBox_19.setObjectName("groupBox_19")
        self.gridLayout5 = QtWidgets.QGridLayout(self.groupBox_19)
        self.gridLayout5.setObjectName("gridLayout5")
        self.rsm_perturbation = QtWidgets.QPlainTextEdit(self.groupBox_19)
        self.rsm_perturbation.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.rsm_perturbation.setObjectName("rsm_perturbation")
        self.gridLayout5.addWidget(self.rsm_perturbation, 1, 1, 1, 1)
        spacerItem14 = QtWidgets.QSpacerItem(
            20, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum
        )
        self.gridLayout5.addItem(spacerItem14, 1, 0, 1, 1)
        self.rsm_perturbation_header = QtWidgets.QLabel(self.groupBox_19)
        self.rsm_perturbation_header.setObjectName("rsm_perturbation_header")
        self.gridLayout5.addWidget(self.rsm_perturbation_header, 0, 0, 1, 2)
        self.gridLayout4.addWidget(self.groupBox_19, 3, 0, 1, 3)
        self.horizontalLayout_99.addWidget(self.groupBox_31)
        self.horizontalLayout_43 = QtWidgets.QGridLayout()
        self.horizontalLayout_43.setObjectName("horizontalLayout_43")
        self.rsm_predict_progress_major = QtWidgets.QProgressBar(
            self.rsm_predict_tab
        )
        self.rsm_predict_progress_major.setProperty("value", 0)
        self.rsm_predict_progress_major.setObjectName(
            "rsm_predict_progress_major"
        )
        self.horizontalLayout_43.addWidget(
            self.rsm_predict_progress_major, 1, 0, 1, 1
        )
        self.rsm_predict = QtWidgets.QPushButton(self.rsm_predict_tab)
        self.rsm_predict.setObjectName("rsm_predict")
        self.horizontalLayout_43.addWidget(self.rsm_predict, 0, 0, 1, 1)
        self.rsm_predict_progress_minor = QtWidgets.QProgressBar(
            self.rsm_predict_tab
        )
        self.rsm_predict_progress_minor.setProperty("value", 0)
        self.rsm_predict_progress_minor.setObjectName(
            "rsm_predict_progress_minor"
        )
        self.horizontalLayout_43.addWidget(
            self.rsm_predict_progress_minor, 2, 0, 1, 1
        )
        self.horizontalLayout_99.addLayout(self.horizontalLayout_43)
        self.rsm_subtab.addTab(self.rsm_predict_tab, "")
        self.rsm_prediction_tab = QtWidgets.QWidget()
        self.rsm_prediction_tab.setObjectName("rsm_prediction_tab")
        self.horizontalLayout_910 = QtWidgets.QVBoxLayout(
            self.rsm_prediction_tab
        )
        self.horizontalLayout_910.setObjectName("horizontalLayout_910")
        self.rsm_results_subtab = QtWidgets.QTabWidget(self.rsm_prediction_tab)
        self.rsm_results_subtab.setObjectName("rsm_results_subtab")
        self.rsm_ccnplot_tab = QtWidgets.QWidget()
        self.rsm_ccnplot_tab.setObjectName("rsm_ccnplot_tab")
        self.rsm_results_subtab.addTab(self.rsm_ccnplot_tab, "")
        self.rsm_diffplot_tab = QtWidgets.QWidget()
        self.rsm_diffplot_tab.setObjectName("rsm_diffplot_tab")
        self.rsm_results_subtab.addTab(self.rsm_diffplot_tab, "")
        self.horizontalLayout_910.addWidget(self.rsm_results_subtab)
        self.rsm_subtab.addTab(self.rsm_prediction_tab, "")
        self.horizontalLayout_97.addWidget(self.rsm_subtab)
        self.tabWidget.addTab(self.rsm_tab, "")
        self.gridLayout_8.addWidget(self.tabWidget, 2, 0, 1, 2)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setEnabled(True)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1007, 25))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuSettings = QtWidgets.QMenu(self.menubar)
        self.menuSettings.setObjectName("menuSettings")
        self.menuStyle = QtWidgets.QMenu(self.menuSettings)
        self.menuStyle.setObjectName("menuStyle")
        self.menuFont = QtWidgets.QMenu(self.menuSettings)
        self.menuFont.setObjectName("menuFont")
        MainWindow.setMenuBar(self.menubar)
        self.actionSave_2 = QtWidgets.QAction(MainWindow)
        self.actionSave_2.setObjectName("actionSave_2")
        self.actionQuit_Ctrl_Q = QtWidgets.QAction(MainWindow)
        self.actionQuit_Ctrl_Q.setObjectName("actionQuit_Ctrl_Q")
        self.actionOpen = QtWidgets.QAction(MainWindow)
        self.actionOpen.setObjectName("actionOpen")
        self.actionPrint = QtWidgets.QAction(MainWindow)
        self.actionPrint.setObjectName("actionPrint")
        self.actionSave_to_current = QtWidgets.QAction(MainWindow)
        self.actionSave_to_current.setObjectName("actionSave_to_current")
        self.actionCreate_output_directories = QtWidgets.QAction(MainWindow)
        self.actionCreate_output_directories.setObjectName(
            "actionCreate_output_directories"
        )
        self.actionLoad_minimal_settings = QtWidgets.QAction(MainWindow)
        self.actionLoad_minimal_settings.setObjectName(
            "actionLoad_minimal_settings"
        )
        self.actionAbout_SOSAA = QtWidgets.QAction(MainWindow)
        self.actionAbout_SOSAA.setObjectName("actionAbout_SOSAA")
        self.actionSOSAA_webpage = QtWidgets.QAction(MainWindow)
        self.actionSOSAA_webpage.setObjectName("actionSOSAA_webpage")
        self.actionOnline_manual = QtWidgets.QAction(MainWindow)
        self.actionOnline_manual.setEnabled(False)
        self.actionOnline_manual.setObjectName("actionOnline_manual")
        self.actionFileHelp = QtWidgets.QAction(MainWindow)
        self.actionFileHelp.setEnabled(False)
        self.actionFileHelp.setObjectName("actionFileHelp")
        self.actionSave_as_defaults = QtWidgets.QAction(MainWindow)
        self.actionSave_as_defaults.setObjectName("actionSave_as_defaults")
        self.actionOpen_output_directory = QtWidgets.QAction(MainWindow)
        self.actionOpen_output_directory.setObjectName(
            "actionOpen_output_directory"
        )
        self.actionSet_Global_Font = QtWidgets.QAction(MainWindow)
        self.actionSet_Global_Font.setObjectName("actionSet_Global_Font")
        self.actionReset_Fonts = QtWidgets.QAction(MainWindow)
        self.actionReset_Fonts.setObjectName("actionReset_Fonts")
        self.actionLight = QtWidgets.QAction(MainWindow)
        self.actionLight.setCheckable(True)
        self.actionLight.setObjectName("actionLight")
        self.actionDark = QtWidgets.QAction(MainWindow)
        self.actionDark.setCheckable(True)
        self.actionDark.setObjectName("actionDark")
        self.actionChange_Colour = QtWidgets.QAction(MainWindow)
        self.actionChange_Colour.setObjectName("actionChange_Colour")
        self.actionSystem = QtWidgets.QAction(MainWindow)
        self.actionSystem.setCheckable(True)
        self.actionSystem.setObjectName("actionSystem")
        self.actionReset_Style = QtWidgets.QAction(MainWindow)
        self.actionReset_Style.setObjectName("actionReset_Style")
        self.actionRecompile_model = QtWidgets.QAction(MainWindow)
        self.actionRecompile_model.setObjectName("actionRecompile_model")
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionSave_to_current)
        self.menuFile.addAction(self.actionSave_2)
        self.menuFile.addAction(self.actionSave_as_defaults)
        self.menuFile.addAction(self.actionCreate_output_directories)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionLoad_minimal_settings)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionPrint)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit_Ctrl_Q)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionFileHelp)
        self.menuTools.addSeparator()
        self.menuTools.addAction(self.actionOpen_output_directory)
        self.menuTools.addAction(self.actionRecompile_model)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout_SOSAA)
        self.menuHelp.addAction(self.actionSOSAA_webpage)
        self.menuHelp.addAction(self.actionOnline_manual)
        self.menuStyle.addAction(self.actionSystem)
        self.menuStyle.addAction(self.actionLight)
        self.menuStyle.addAction(self.actionDark)
        self.menuStyle.addSeparator()
        self.menuStyle.addAction(self.actionChange_Colour)
        self.menuStyle.addSeparator()
        self.menuStyle.addAction(self.actionReset_Style)
        self.menuFont.addAction(self.actionSet_Global_Font)
        self.menuFont.addSeparator()
        self.menuFont.addAction(self.actionReset_Fonts)
        self.menuSettings.addAction(self.menuStyle.menuAction())
        self.menuSettings.addAction(self.menuFont.menuAction())
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuSettings.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        self.sosaa_subtab.setCurrentIndex(0)
        self.rsm_subtab.setCurrentIndex(0)
        self.rsm_results_subtab.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.description, self.flag_gasdrydep)
        MainWindow.setTabOrder(self.flag_gasdrydep, self.customKey_1)
        MainWindow.setTabOrder(self.customKey_1, self.customVal_1)
        MainWindow.setTabOrder(self.customVal_1, self.customKey_2)
        MainWindow.setTabOrder(self.customKey_2, self.customVal_2)
        MainWindow.setTabOrder(self.customVal_2, self.customKey_3)
        MainWindow.setTabOrder(self.customKey_3, self.customVal_3)
        MainWindow.setTabOrder(self.customVal_3, self.customKey_4)
        MainWindow.setTabOrder(self.customKey_4, self.customVal_4)
        MainWindow.setTabOrder(self.customVal_4, self.customKey_5)
        MainWindow.setTabOrder(self.customKey_5, self.customVal_5)
        MainWindow.setTabOrder(self.customVal_5, self.customKey_6)
        MainWindow.setTabOrder(self.customKey_6, self.customVal_6)
        MainWindow.setTabOrder(self.customVal_6, self.customKey_7)
        MainWindow.setTabOrder(self.customKey_7, self.customVal_7)
        MainWindow.setTabOrder(self.customVal_7, self.customKey_8)
        MainWindow.setTabOrder(self.customKey_8, self.customVal_8)
        MainWindow.setTabOrder(self.customVal_8, self.customKey_9)
        MainWindow.setTabOrder(self.customKey_9, self.customVal_9)
        MainWindow.setTabOrder(self.customVal_9, self.customKey_10)
        MainWindow.setTabOrder(self.customKey_10, self.customVal_10)
        MainWindow.setTabOrder(self.customVal_10, self.customKey_11)
        MainWindow.setTabOrder(self.customKey_11, self.customVal_11)
        MainWindow.setTabOrder(self.customVal_11, self.customKey_12)
        MainWindow.setTabOrder(self.customKey_12, self.customVal_12)
        MainWindow.setTabOrder(self.customVal_12, self.customKey_13)
        MainWindow.setTabOrder(self.customKey_13, self.customVal_13)
        MainWindow.setTabOrder(self.customVal_13, self.customKey_14)
        MainWindow.setTabOrder(self.customKey_14, self.customVal_14)
        MainWindow.setTabOrder(self.customVal_14, self.customKey_15)
        MainWindow.setTabOrder(self.customKey_15, self.customVal_15)
        MainWindow.setTabOrder(self.customVal_15, self.customKey_16)
        MainWindow.setTabOrder(self.customKey_16, self.customVal_16)
        MainWindow.setTabOrder(self.customVal_16, self.customKey_17)
        MainWindow.setTabOrder(self.customKey_17, self.customVal_17)
        MainWindow.setTabOrder(self.customVal_17, self.customKey_18)
        MainWindow.setTabOrder(self.customKey_18, self.customVal_18)
        MainWindow.setTabOrder(self.customVal_18, self.customKey_19)
        MainWindow.setTabOrder(self.customKey_19, self.customVal_19)
        MainWindow.setTabOrder(self.customVal_19, self.customKey_20)
        MainWindow.setTabOrder(self.customKey_20, self.customVal_20)
        MainWindow.setTabOrder(self.customVal_20, self.customKey_21)
        MainWindow.setTabOrder(self.customKey_21, self.customVal_21)
        MainWindow.setTabOrder(self.customVal_21, self.customKey_22)
        MainWindow.setTabOrder(self.customKey_22, self.customVal_22)
        MainWindow.setTabOrder(self.customVal_22, self.customKey_23)
        MainWindow.setTabOrder(self.customKey_23, self.customVal_23)
        MainWindow.setTabOrder(self.customVal_23, self.customKey_24)
        MainWindow.setTabOrder(self.customKey_24, self.customVal_24)
        MainWindow.setTabOrder(self.customVal_24, self.customKey_25)
        MainWindow.setTabOrder(self.customKey_25, self.customVal_25)
        MainWindow.setTabOrder(self.customVal_25, self.customKey_26)
        MainWindow.setTabOrder(self.customKey_26, self.customVal_26)
        MainWindow.setTabOrder(self.customVal_26, self.customKey_27)
        MainWindow.setTabOrder(self.customKey_27, self.customVal_27)
        MainWindow.setTabOrder(self.customVal_27, self.customKey_28)
        MainWindow.setTabOrder(self.customKey_28, self.customVal_28)
        MainWindow.setTabOrder(self.customVal_28, self.customKey_29)
        MainWindow.setTabOrder(self.customKey_29, self.customVal_29)
        MainWindow.setTabOrder(self.customVal_29, self.customKey_30)
        MainWindow.setTabOrder(self.customKey_30, self.customVal_30)
        MainWindow.setTabOrder(self.customVal_30, self.rawEdit)
        MainWindow.setTabOrder(self.rawEdit, self.tabWidget)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.label_7.setText(_translate("MainWindow", "Current output path:"))
        self.label_13.setText(_translate("MainWindow", "Current INITFILE:"))
        self.groupBox_9.setTitle(_translate("MainWindow", "Directory paths"))
        self.browse_output.setText(_translate("MainWindow", "..."))
        self.label_28.setText(_translate("MainWindow", "Output"))
        self.label_281.setText(_translate("MainWindow", "Input"))
        self.browse_input.setText(_translate("MainWindow", "..."))
        self.browse_code.setText(_translate("MainWindow", "..."))
        self.label_code_dir.setText(_translate("MainWindow", "Code"))
        self.label_chem_dir.setText(_translate("MainWindow", "Chemistry"))
        self.browse_chem.setText(_translate("MainWindow", "..."))
        self.browse_chemname.setText(_translate("MainWindow", "..."))
        self.label_chemname_dir.setText(_translate("MainWindow", "Name"))
        self.browse_case.setText(_translate("MainWindow", "..."))
        self.label_27.setText(_translate("MainWindow", "Case"))
        self.browse_casename.setText(_translate("MainWindow", "..."))
        self.label_casename_dir.setText(_translate("MainWindow", "Name"))
        self.browse_exe.setText(_translate("MainWindow", "..."))
        self.label_sosaa_exe.setText(_translate("MainWindow", ".exe"))
        self.label.setText(_translate("MainWindow", "Main"))
        self.browse_main.setText(_translate("MainWindow", "..."))
        self.groupBox_2.setTitle(
            _translate("MainWindow", "Simulation identifier")
        )
        self.description.setToolTip(
            _translate(
                "MainWindow",
                (
                    "Description of the run, max 1000 characters. This will be"
                    " saved in all output files."
                ),
            )
        )
        self.label_8.setToolTip(
            _translate(
                "MainWindow",
                (
                    "Description of the run, max 1000 characters. This will be"
                    " saved in all output files."
                ),
            )
        )
        self.label_8.setText(_translate("MainWindow", "Desciption:"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.general_tab),
            _translate("MainWindow", "General options"),
        )
        self.groupBox_16.setTitle(_translate("MainWindow", "Modules in use"))
        self.flag_emis.setText(_translate("MainWindow", "Use Emissions"))
        self.flag_emis_soil.setToolTip(
            _translate(
                "MainWindow",
                (
                    "<html><head/><body><p>Soil emissions are not yet"
                    " supported.</p></body></html>"
                ),
            )
        )
        self.flag_emis_soil.setText(
            _translate("MainWindow", "Use Soil emissions")
        )
        self.flag_chem.setTitle(_translate("MainWindow", "Use Chemistry"))
        self.flag_mix_chem.setText(
            _translate(
                "MainWindow", "Enable Vertical Mixing of chemical species"
            )
        )
        self.flag_gasdrydep.setText(
            _translate("MainWindow", "Use Gas dry deposition")
        )
        self.flag_aero.setTitle(_translate("MainWindow", "Use Aerosols"))
        self.flag_mix_aero.setText(
            _translate(
                "MainWindow", "Enable Vertical Mixing of aerosol particles"
            )
        )
        self.aer_nucleation.setText(
            _translate("MainWindow", "Aerosols includes nucleation")
        )
        self.aer_condensation.setText(
            _translate("MainWindow", "Aerosols includes condensation")
        )
        self.aer_coagulation.setText(
            _translate("MainWindow", "Aerosols includes coagulation")
        )
        self.aer_dry_deposition.setText(
            _translate("MainWindow", "Aerosols includes dry deposition")
        )
        self.aer_wet_deposition.setToolTip(
            _translate(
                "MainWindow",
                (
                    "<html><head/><body><p>Aerosol wet deposition is not yet"
                    " supported.</p></body></html>"
                ),
            )
        )
        self.aer_wet_deposition.setText(
            _translate("MainWindow", "Aerosols includes wet deposition")
        )
        self.aer_snow_scavenge.setText(
            _translate("MainWindow", "Aerosols includes snow scavenge")
        )
        self.groupBox_5.setTitle(
            _translate("MainWindow", "Module timestep options")
        )
        self.label_dt_emis.setText(_translate("MainWindow", "Emission"))
        self.dt_emis.setSuffix(_translate("MainWindow", " s"))
        self.dt_aero.setSuffix(_translate("MainWindow", " s"))
        self.label_dt_obs.setText(_translate("MainWindow", "Observation"))
        self.dt_chem.setSuffix(_translate("MainWindow", " s"))
        self.label_dt_chem.setText(_translate("MainWindow", "Chemistry"))
        self.label_dt_mete.setText(_translate("MainWindow", "Meteorology"))
        self.label_dt_depo.setText(
            _translate("MainWindow", "Gas Dry Deposition")
        )
        self.dt_mete.setSuffix(_translate("MainWindow", " s"))
        self.label_dt_aero.setText(_translate("MainWindow", "Aerosol"))
        self.dt_obs.setSuffix(_translate("MainWindow", " s"))
        self.dt_depo.setSuffix(_translate("MainWindow", " s"))
        self.label_dt_uhma.setText(
            _translate("MainWindow", "   Internal Aerosol")
        )
        self.dt_uhma.setSuffix(_translate("MainWindow", " s"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.module_tab),
            _translate("MainWindow", "Module options"),
        )
        self.groupBox_51.setTitle(
            _translate("MainWindow", "Trajectory options")
        )
        self.label_14.setText(_translate("MainWindow", "Duration"))
        self.label_12.setText(_translate("MainWindow", "Time Zone"))
        self.label_3.setText(_translate("MainWindow", "UTC+0.00"))
        self.trajectory_duration.setSuffix(
            _translate("MainWindow", " full days")
        )
        self.groupBox_15.setTitle(_translate("MainWindow", "Runtime options"))
        self.start_date.setDisplayFormat(
            _translate("MainWindow", "dd/MM/yyyy HH:mm:ss")
        )
        self.aero_start_offset.setSuffix(_translate("MainWindow", " h"))
        self.aero_start_offset.setPrefix(_translate("MainWindow", "+"))
        self.label_31.setText(_translate("MainWindow", "Start date"))
        self.end_date.setDisplayFormat(
            _translate("MainWindow", "dd/MM/yyyy HH:mm:ss")
        )
        self.aero_start_label.setText(
            _translate("MainWindow", "Aerosol Start")
        )
        self.aero_start_date.setText(
            _translate("MainWindow", "01/01/2000 00:00:00")
        )
        self.label_18.setText(_translate("MainWindow", "End date"))
        self.groupBox_11.setToolTip(
            _translate(
                "MainWindow",
                (
                    "<html><head/><body><p>Batched simulations are not yet"
                    " supported.</p></body></html>"
                ),
            )
        )
        self.groupBox_11.setTitle(
            _translate(
                "MainWindow", "Create batch (using the current settings)"
            )
        )
        self.batchRangeDay.setText(
            _translate("MainWindow", "Range (inclusive):")
        )
        self.batchRangeDayEnd.setDisplayFormat(
            _translate("MainWindow", "yyyy-MM-dd")
        )
        self.saveBatch.setText(_translate("MainWindow", "Preview batch"))
        self.batchFrFile.setText(_translate("MainWindow", "Pick from file"))
        self.batchRangeDayBegin.setDisplayFormat(
            _translate("MainWindow", "yyyy-MM-dd")
        )
        self.batchRangeInd.setText(
            _translate("MainWindow", "Indices (inclusive)")
        )
        self.createBashFile.setText(
            _translate("MainWindow", "Create bash file")
        )
        self.helpBatch.setText(_translate("MainWindow", "?"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.scenario_tab),
            _translate("MainWindow", "Scenario options"),
        )
        self.groupBox_4.setTitle(
            _translate("MainWindow", "Lists of Chemical Species")
        )
        self.groupBox_6.setTitle(
            _translate("MainWindow", "Condensable Species")
        )
        self.flag_vapor.setTitle(
            _translate(
                "MainWindow", "Uncheck to Save All, Check to Select Explicitly"
            )
        )
        self.group_output_list_Vd.setTitle(
            _translate("MainWindow", "Dry Deposition Velocities")
        )
        self.group_output_list_emi.setTitle(
            _translate("MainWindow", "Emission Rates")
        )
        self.groupBox_12.setTitle(_translate("MainWindow", "Output Species"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.output_tab),
            _translate("MainWindow", "Output options"),
        )
        self.groupBox.setTitle(_translate("MainWindow", "NML_CUSTOM"))
        self.label_16.setText(_translate("MainWindow", "Variable"))
        self.label_24.setText(_translate("MainWindow", "Value"))
        self.label_30.setText(_translate("MainWindow", "Variable"))
        self.label_29.setText(_translate("MainWindow", "Value"))
        self.groupBox_7.setTitle(_translate("MainWindow", "Raw input"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.custom_tab),
            _translate("MainWindow", "Custom options"),
        )
        self.label_131.setText(
            _translate(
                "MainWindow", "Current unsaved in-memory INITFILE state:"
            )
        )
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.initfile_tab),
            _translate("MainWindow", "INITFILE"),
        )
        self.compile_stop.setText(
            _translate("MainWindow", "Kill the Terminal")
        )
        self.compile_start.setText(_translate("MainWindow", "Run Compilation"))
        self.compile_clean.setText(
            _translate("MainWindow", "Clean SOSAA Artefacts")
        )
        self.compile_cleanchem.setText(
            _translate("MainWindow", "Clean Chemistry Artefacts")
        )
        self.sosaa_subtab.setTabText(
            self.sosaa_subtab.indexOf(self.compile_tab),
            _translate("MainWindow", "Compile SOSAA"),
        )
        self.groupBox_3.setTitle(_translate("MainWindow", "Launch options"))
        self.launch_cmd.setText(
            _translate("MainWindow", "orterun --oversubscribe -n 4")
        )
        self.label_4.setText(_translate("MainWindow", "Launch command"))
        self.flag_debug.setText(
            _translate("MainWindow", "Enable Debug output")
        )
        self.model_stop.setText(_translate("MainWindow", "Kill the Terminal"))
        self.model_start.setText(_translate("MainWindow", "Run SOSAA"))
        self.sosaa_subtab.setTabText(
            self.sosaa_subtab.indexOf(self.run_tab),
            _translate("MainWindow", "Run SOSAA"),
        )
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.sosaa_tab),
            _translate("MainWindow", "SOSAA Live"),
        )
        self.groupBox_17.setTitle(
            _translate("MainWindow", "SOSAA RSM training options")
        )
        self.label_2.setText(_translate("MainWindow", "RSM Path"))
        self.label_6.setText(_translate("MainWindow", "Training Seed"))
        self.label_5.setText(_translate("MainWindow", "Random Forest Size"))
        self.browse_rsm.setText(_translate("MainWindow", "..."))
        self.label_9.setText(_translate("MainWindow", "Bootstrap Samples"))
        self.rsm_build.setText(
            _translate("MainWindow", "Train the SOSAA RSM and Save to File")
        )
        self.rsm_load.setText(
            _translate("MainWindow", "Load the SOSAA RSM from a File")
        )
        self.groupBox_18.setTitle(
            _translate("MainWindow", "SOSAA RSM Test Performance")
        )
        self.label_21.setText(
            _translate(
                "MainWindow", "Training Set Mean Squared Prediction Error:"
            )
        )
        self.label_61.setText(
            _translate(
                "MainWindow", "Training Set Mean Absolute Prediction Error:"
            )
        )
        self.label_11.setText(
            _translate("MainWindow", "Test Set Mean Squared Prediction Error:")
        )
        self.label_51.setText(
            _translate("MainWindow", "Training Set R2 Score:")
        )
        self.label_19.setText(
            _translate(
                "MainWindow", "Test Set Mean Absolute Prediction Error:"
            )
        )
        self.label_23.setText(_translate("MainWindow", "Test Set R2 Score:"))
        self.label_231.setText(
            _translate("MainWindow", "Test Set Uncertainty Calibration Error:")
        )
        self.label_232.setText(
            _translate(
                "MainWindow", "Training Set Uncertainty Calibration Error:"
            )
        )
        self.rsm_subtab.setTabText(
            self.rsm_subtab.indexOf(self.rsm_build_tab),
            _translate("MainWindow", "Configure and Train"),
        )
        self.groupBox_31.setTitle(
            _translate("MainWindow", "SOSAA RSM prediction options")
        )
        self.label_22.setText(_translate("MainWindow", "Output Path"))
        self.label_52.setText(_translate("MainWindow", "Bootstrap Samples"))
        self.browse_rsm_output.setText(_translate("MainWindow", "..."))
        self.label_62.setText(_translate("MainWindow", "Prediction Seed"))
        self.groupBox_19.setTitle(
            _translate("MainWindow", "Input Perturbations")
        )
        self.rsm_perturbation.setPlaceholderText(
            _translate("MainWindow", "return inputs")
        )
        self.rsm_predict.setText(
            _translate(
                "MainWindow", "Generate SOSAA RSM Predictions and Save to File"
            )
        )
        self.rsm_subtab.setTabText(
            self.rsm_subtab.indexOf(self.rsm_predict_tab),
            _translate("MainWindow", "Generate Predictions"),
        )
        self.rsm_results_subtab.setTabText(
            self.rsm_results_subtab.indexOf(self.rsm_ccnplot_tab),
            _translate("MainWindow", "CCN Profile"),
        )
        self.rsm_results_subtab.setTabText(
            self.rsm_results_subtab.indexOf(self.rsm_diffplot_tab),
            _translate("MainWindow", "CCN Difference"),
        )
        self.rsm_subtab.setTabText(
            self.rsm_subtab.indexOf(self.rsm_prediction_tab),
            _translate("MainWindow", "Visualise Results"),
        )
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.rsm_tab),
            _translate("MainWindow", "SOSAA RSM"),
        )
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuTools.setTitle(_translate("MainWindow", "Tools"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.menuSettings.setTitle(_translate("MainWindow", "Settings"))
        self.menuStyle.setTitle(_translate("MainWindow", "Style"))
        self.menuFont.setTitle(_translate("MainWindow", "Font"))
        self.actionSave_2.setText(_translate("MainWindow", "Save As"))
        self.actionSave_2.setShortcut(_translate("MainWindow", "Ctrl+Shift+S"))
        self.actionQuit_Ctrl_Q.setText(_translate("MainWindow", "Quit"))
        self.actionQuit_Ctrl_Q.setToolTip(
            _translate("MainWindow", "Quit without save")
        )
        self.actionQuit_Ctrl_Q.setShortcut(_translate("MainWindow", "Ctrl+Q"))
        self.actionOpen.setText(_translate("MainWindow", "Load settings"))
        self.actionOpen.setShortcut(_translate("MainWindow", "Ctrl+O"))
        self.actionPrint.setText(
            _translate("MainWindow", "Print current INIT")
        )
        self.actionPrint.setShortcut(_translate("MainWindow", "Ctrl+P"))
        self.actionSave_to_current.setText(
            _translate("MainWindow", "Save to current")
        )
        self.actionSave_to_current.setShortcut(
            _translate("MainWindow", "Ctrl+S")
        )
        self.actionCreate_output_directories.setText(
            _translate("MainWindow", "Create output directories")
        )
        self.actionCreate_output_directories.setShortcut(
            _translate("MainWindow", "Ctrl+D")
        )
        self.actionLoad_minimal_settings.setText(
            _translate("MainWindow", "Load minimal settings")
        )
        self.actionAbout_SOSAA.setText(_translate("MainWindow", "About SOSAA"))
        self.actionSOSAA_webpage.setText(
            _translate("MainWindow", "SOSAA webpage")
        )
        self.actionOnline_manual.setText(
            _translate("MainWindow", "Online manual")
        )
        self.actionFileHelp.setText(_translate("MainWindow", "Help"))
        self.actionSave_as_defaults.setText(
            _translate("MainWindow", "Save as defaults")
        )
        self.actionOpen_output_directory.setText(
            _translate("MainWindow", "Open output dir with file browser")
        )
        self.actionSet_Global_Font.setText(
            _translate("MainWindow", "Set Global Font")
        )
        self.actionReset_Fonts.setText(_translate("MainWindow", "Reset Fonts"))
        self.actionLight.setText(_translate("MainWindow", "Light"))
        self.actionDark.setText(_translate("MainWindow", "Dark"))
        self.actionChange_Colour.setText(
            _translate("MainWindow", "Change Colour")
        )
        self.actionSystem.setText(_translate("MainWindow", "System"))
        self.actionReset_Style.setText(_translate("MainWindow", "Reset Style"))
        self.actionRecompile_model.setText(
            _translate("MainWindow", "Recompile the SOSAA model")
        )
        self.actionRecompile_model.setShortcut(
            _translate("MainWindow", "Ctrl+Shift+R")
        )


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
